library(dplyr)
library(BIOMASS)
library(ggplot2)
library(data.table)
library(tidyr)
library(lme4)
library(vegan)
library(effects)
library(MASS)
library(blme)
library(ape)
library(multcomp)
library(ggsignif)
library(cowplot)
library(gamm4)
library(piecewiseSEM)
library(gridExtra)
library(grid)
library(GGally)
library(ggfortify)




#### READ IN DATA ####

# these data are available as a supplement to this R code
# veg_plot_summary.csv

# change to correct file path
plot_carbon <- read.csv("D:/carbon stock assessment/Data/upload summary/veg_plot_summary.csv")

str(plot_carbon)

# order forest type
plot_carbon$Forest_type <- factor(plot_carbon$Forest_type,
                                  levels = c("HCV",
                                             "Continuous logged",
                                             "Continuous primary"))





# set colours for the C stock components for plotting

cbPalette2 <- c("#999999", "#F0E442", "#56B4E9", "#009E73", "#E69F00", "#0072B2", "#D55E00", "#CC79A7")

# set colours for the Forest_type, to match the colours I used on the map
forest_type_col <- c("HCV" = "#8F8F8F", 
                     "Continuous logged" = "#88cd66",
                     "Continuous primary" = "#095E06")






###### COMPARING C ESTIMATES FOR DIFFERENT HEIGHT MODELS ########
# live trees and palms carbon only - because this is what I present in main text of manuscript

# test stastically (pearson correlation coef)
# and label plots with the stats

comp_cor_a <- cor.test(plot_carbon$Tree_palm_carbon_Mgha,
                       plot_carbon$Tree_palm_carbon_chaveE_Mgha,
                       method = "pearson",
                       use = "pairwise.complete.obs")

# t = 25.0, df = 47, p-value < 2.2e-16
#  cor 
# 0.964 



comp_a <- ggplot(plot_carbon)+
  geom_point(aes(x = Tree_palm_carbon_Mgha,
                 y = Tree_palm_carbon_chaveE_Mgha,
                 col = Forest_type))+
  scale_colour_manual(values = forest_type_col,
                      name = "Forest type")+
  geom_abline(slope = 1, intercept = 0, linetype = "dashed")+
  theme_classic() +
  coord_fixed() + # x and y scales are the same
  scale_x_continuous(limits = c(0,225), expand = c(0,0))+
  # sets limits and removes gap between lower limit and the axis
  scale_y_continuous(limits = c(0,225), expand = c(0,0)) +
  xlab(bquote("AGC/Mgha"^-1*" (log-log model)")) +
  ylab(bquote("AGC/Mgha"^-1*" (climatic model)")) +
  annotate("text",
           label = "italic(r) == 0.964",
           x = 40, y = 195,
           size = 4,
           parse = T)+ # formats text
  annotate("text",
           label = "italic(df) == 47",
           x = 40, y = 180,
           size = 4,
           parse = T)+ # formats text
  annotate("text",
           label = "italic(p) < 0.001",
           x = 40, y = 165,
           size = 4,
           parse = T)+ # formats text
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        legend.position = "top") # for plot_grid




comp_cor_b <- cor.test(plot_carbon$Tree_palm_carbon_Mgha,
                       plot_carbon$Tree_palm_carbon_feldpausch_Mgha,
                       method = "pearson",
                       use = "pairwise.complete.obs")

#t = 34.7, df = 47, p-value < 2.2e-16
#      cor 
# 0.981 

comp_b <- ggplot(plot_carbon)+
  geom_point(aes(x = Tree_palm_carbon_Mgha,
                 y = Tree_palm_carbon_feldpausch_Mgha,
                 col = Forest_type))+
  scale_colour_manual(values = forest_type_col,
                      name = "Forest type")+
  geom_abline(slope = 1, intercept = 0, linetype = "dashed")+
  theme_classic() +
  annotate("text",
           label = "italic(r) == 0.981",
           x = 40, y = 195,
           size = 4,
           parse = T)+ # formats text
  annotate("text",
           label = "italic(df) == 47",
           x = 40, y = 180,
           size = 4,
           parse = T)+ # formats text
  annotate("text",
           label = "italic(p) < 0.001",
           x = 40, y = 165,
           size = 4,
           parse = T)+ # formats text
  coord_fixed() + # x and y scales are the same
  scale_x_continuous(limits = c(0,225), expand = c(0,0))+
  # sets limits and removes gap between lower limit and the axis
  scale_y_continuous(limits = c(0,225), expand = c(0,0)) +
  xlab(bquote("AGC/Mgha"^-1*" (log-log model)")) +
  ylab(bquote("AGC/Mgha"^-1*" (regional model)")) +
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"))



comp_cor_c <- cor.test(plot_carbon$Tree_palm_carbon_chaveE_Mgha,
                       plot_carbon$Tree_palm_carbon_feldpausch_Mgha,
                       method = "pearson",
                       use = "pairwise.complete.obs")

# t = 57.8, df = 47, p-value < 2.2e-16

#sample estimates:
#cor 
#0.993

comp_c <- ggplot(plot_carbon)+
  geom_point(aes(x = Tree_palm_carbon_chaveE_Mgha,
                 y = Tree_palm_carbon_feldpausch_Mgha,
                 col = Forest_type))+
  scale_colour_manual(values = forest_type_col,
                      name = "Forest type")+
  geom_abline(slope = 1, intercept = 0, linetype = "dashed")+
  theme_classic() +
  annotate("text",
           label = "italic(r) == 0.993",
           x = 40, y = 195,
           size = 4,
           parse = T)+ # formats text
  annotate("text",
           label = "italic(df) == 47",
           x = 40, y = 180,
           size = 4,
           parse = T)+ # formats text
  annotate("text",
           label = "italic(p) < 0.001",
           x = 40, y = 165,
           size = 4,
           parse = T)+ # formats text
  coord_fixed() + # x and y scales are the same
  scale_x_continuous(limits = c(0,225), expand = c(0,0))+
  # sets limits and removes gap between lower limit and the axis
  scale_y_continuous(limits = c(0,225), expand = c(0,0)) +
  xlab(bquote("AGC/Mgha"^-1*" (climatic model)")) +
  ylab(bquote("AGC/Mgha"^-1*" (regional model)")) +
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"))











######### C STOCKS OF OIL PALM ############


######## equations for estimating oil palm carbon

# functions for OP carbon from Carlson et al 
# mean 5.97*x^0.62
# low -2.7+2.35*x+(-0.04)*x^2
# high 13.57+1.83*x+(-0.003)*x^2

# note that in the paper low and high are the other way round, in order to get maximum and minimum
# values of C flux when converting forest to OP

# getting average height of curve between values - mean value theorem for definite integrals
# (1/(b-a)) * integral of curve
# gives the mean height of the curve between a and b

f_mean <- function(x){5.97*x^0.62}
f_low <- function(x){-2.7+2.35*x+(-0.04)*x^2}
f_high <- function(x){13.57+1.83*x+(-0.003)*x^2}



# for 0-30 year time average AG carbon stock

f_mean_int_30 <- integrate(f_mean, lower = 0, upper = 30, rel.tol = 100000)
OP_C_mean <- f_mean_int_30$value/(30-0) # 30.35818

f_low_int_30 <- integrate(f_low, lower = 0, upper = 30, rel.tol = 100000)
OP_C_low <- f_low_int_30$value/(30-0) # 20.55

f_high_int_30 <- integrate(f_high, lower = 0, upper = 30)
OP_C_high <- f_high_int_30$value/(30-0) # 40.12


# calculating SE for 0-30 years

# using the mean of upper and lower as the mean for this calculation, so that it is 
# exactly central
OP_C_mean <- mean(c(OP_C_high, OP_C_low)) # 30.335

OP_C_SE <- (OP_C_high - OP_C_mean)/1.96 # SE = 4.99

# SE = SD/sqrt(n)
# so SD = SE * sqrt(n)
OP_C_SD <- ((40.12-30.335)/1.96) * sqrt(15)
# 19.33528


####### Generate oil palm carbon data to use in lme ##########

# generate n = 15 data points (number used to derive relationships in orignal study)
# with mean and SD to match those of OP above


OP_C <- mvrnorm(n = 15,
                mu = OP_C_mean,
                Sigma = OP_C_SD^2,
                empirical = TRUE)

# if reusing - save and to use same data each time
#saveRDS(OP_C, "OP_C.RData")

# read in each time to ensure same randomly generated values are used
#OP_C <- readRDS("OP_C.RData")


mean(OP_C) # 30.335 - as specified
sd(OP_C) # 19.335 - as specified
sd(OP_C)/sqrt(length(OP_C)) # 4.99 - matches with original


plot(OP_C)





#################### RESULT 1 SUMMARISING C STOCKS ###################


############ SUMMARZING BY LAND-USE TYPE #########

##### TOTAL C STOCKS #####

colnames(plot_carbon)


####### add oil palm simulated data to plot_carbon #######

# write blank dataframe with same columns as plot_carbon and 15 rows
plot_carbon_op <- plot_carbon[1:15,]
plot_carbon_op[,] <- NA

# write oil palm AGC for each of the tree height methods
# for tree carbon and total carbon 
plot_carbon_op$Total_carbon_Mgha <- OP_C

plot_carbon_op$Tree_palm_carbon_Mgha <- OP_C
plot_carbon_op$Tree_palm_carbon_chaveE_Mgha <- OP_C
plot_carbon_op$Tree_palm_carbon_feldpausch_Mgha <- OP_C

plot_carbon_op$Forest_type <- factor("Oil palm")

# set each one of these as a different site code because they were
# generated as independent data points
plot_carbon_op$Site_code <- factor(paste("OP", c(1:15), sep = ""))


# bind with plot_carbon
plot_carbon_op <- rbind(plot_carbon, plot_carbon_op)

plot_carbon_op$Site_code <- factor(plot_carbon_op$Site_code)
plot_carbon_op$Forest_type <- factor(plot_carbon_op$Forest_type)





##### Testing the difference in total C stocks between landuse type #######

##### Difference for plot-level carbon #######
# live tree carbon only


#  uninformative prior for random effect sd
plot_c_lme <- blmer(Tree_palm_carbon_Mgha ~ Forest_type +
                         (1|Site_code), # random intercept
                       data = plot_carbon_op, 
                       REML=FALSE,
                       cov.prior = gamma(shape = 2.5, rate = 0), 
                       control = lmerControl(optimizer ="Nelder_Mead"))


summary(plot_c_lme)
# random effect SD is 8.2

anova(plot_c_lme)
#Analysis of Variance Table
#            Df Sum Sq Mean Sq F value
#Forest_type  3  40337   13446  22.054

drop1(plot_c_lme, test="Chisq") # likelihood ratio test against random effect-only model
# LRT is chisq value
#             Df    AIC    LRT   Pr(Chi)    
#<none>         610.39                     
#Forest_type  3 642.81 38.427 2.295e-08 ***


# normality of random effect
hist(unlist(ranef(plot_c_lme)$Site_code), col="grey")

# spread of residuals
plot(plot_c_lme) 

# QQ plot to check normality of residuals
qqnorm(resid(plot_c_lme))




### calculate Moran's I to check for spatial autocorrelation ####
# for field plots only

resid_AGC <- data.frame(resid = residuals(plot_c_lme),
                   Site_plot_code = plot_carbon_op$Site_plot_code)

moran.df <- dplyr::select(plot_carbon, 
                          Site_plot_code,
                          Latitude,
                          Longitude)%>%
  left_join(resid_AGC,
            by = "Site_plot_code")

# calculate inverse distance matrix
resid.dists <- as.matrix(dist(cbind(moran.df$Longitude,
                                    moran.df$Latitude)))
resid.dists.inv <- 1/resid.dists
diag(resid.dists.inv) <- 0


Moran.I(moran.df$resid, resid.dists.inv)
#$observed
#[1] -0.1901006

#$expected
#[1] -0.02083333

#$sd
#[1] 0.1316959

#$p.value
#[1] 0.1986913






#### post-hoc test: pairwise difference p vals
plot_c_lme_tukey <- glht(plot_c_lme, mcp(Forest_type = "Tukey")) 
summary(plot_c_lme_tukey)

#                                              Estimate Std. Error z value Pr(>|z|)    
#  Continuous logged - HCV == 0                  47.843     12.530   3.818   <0.001 ***
#  Continuous primary - HCV == 0                 73.637     12.530   5.877   <0.001 ***
#  Oil palm - HCV == 0                          -22.470      8.162  -2.753   0.0278 *  
#  Continuous primary - Continuous logged == 0   25.794     16.465   1.567   0.3839    
#  Oil palm - Continuous logged == 0            -70.313     13.443  -5.230   <0.001 ***
#  Oil palm - Continuous primary == 0           -96.106     13.443  -7.149   <0.001 ***






#### for supp info: using different estimates of tree height #####

#### chave height

#  uninformative prior for random effect sd
plot_c_lme_chave <- blmer(Tree_palm_carbon_chaveE_Mgha ~ Forest_type +
                         (1|Site_code), # random intercept
                       data = plot_carbon_op, 
                       REML=FALSE,
                       cov.prior = gamma(shape = 2.5, rate = 0), 
                       control = lmerControl(optimizer ="Nelder_Mead"))

summary(plot_c_lme_chave)
# random effect SD is 9.94
# AGC in HCVs is 69.1Mg/ha

anova(plot_c_lme_chave)
#            Df Sum Sq Mean Sq F value
# Forest_type  3  32830   10943  17.897

drop1(plot_c_lme_chave, test="Chisq") # likelihood ratio test against random effect-only model
#             Df    AIC    LRT   Pr(Chi)    
#<none>         613.03                     
#Forest_type  3 642.51 35.478 9.656e-08 ***


# normality of random effect
hist(unlist(ranef(plot_c_lme_chave)$Site_code), col="grey")

# spread of residuals
plot(plot_c_lme_chave) 

# QQ plot to check normality of residuals
qqnorm(resid(plot_c_lme_chave))


#### post-hoc test: pairwise difference p vals
plot_c_lme_tukey_chave <- glht(plot_c_lme_chave, mcp(Forest_type = "Tukey")) 
summary(plot_c_lme_tukey_chave)

#                                              Estimate Std. Error z value Pr(>|z|)    
#  Continuous logged - HCV == 0                  34.270     13.233   2.590  0.04446 *  
#  Continuous primary - HCV == 0                 47.895     13.233   3.620  0.00152 ** 
#  Oil palm - HCV == 0                          -38.788      8.433  -4.600  < 0.001 ***
#  Continuous primary - Continuous logged == 0   13.625     17.398   0.783  0.85533    
#  Oil palm - Continuous logged == 0            -73.059     14.096  -5.183  < 0.001 ***
#  Oil palm - Continuous primary == 0           -86.683     14.096  -6.150  < 0.001 ***
  




#### Feldpausch height

#  uninformative prior for random effect sd
plot_c_lme_feldpausch <- blmer(Tree_palm_carbon_feldpausch_Mgha ~ Forest_type +
                               (1|Site_code), # random intercept
                             data = plot_carbon_op, 
                             REML=FALSE,
                             cov.prior = gamma(shape = 2.5, rate = 0), 
                             control = lmerControl(optimizer ="Nelder_Mead"))

summary(plot_c_lme_feldpausch)
# random effect SD is 9.4
# HCV AGC is 68.4 Mg/ha

anova(plot_c_lme_feldpausch)
#            Df Sum Sq Mean Sq F value
#Forest_type  3  42318   14106  21.509

drop1(plot_c_lme_feldpausch, test="Chisq") # likelihood ratio test against random effect-only model
#            Df    AIC   LRT   Pr(Chi)    
#<none>         616.26                    
#Forest_type  3 649.68 39.42 1.414e-08 ***

# normality of random effect
hist(unlist(ranef(plot_c_lme_feldpausch)$Site_code), col="grey")

# spread of residuals
plot(plot_c_lme_feldpausch) 

# QQ plot to check normality of residuals
qqnorm(resid(plot_c_lme_feldpausch))


#### post-hoc test: pairwise difference p vals
plot_c_lme_tukey_feldpausch <- glht(plot_c_lme_feldpausch, mcp(Forest_type = "Tukey")) 
summary(plot_c_lme_tukey_feldpausch)

#                                            Estimate Std. Error z value Pr(>|z|)    
#  Continuous logged - HCV == 0                  44.657     13.340   3.348  0.00465 ** 
#  Continuous primary - HCV == 0                 58.756     13.340   4.404  < 0.001 ***
#  Oil palm - HCV == 0                          -38.084      8.595  -4.431  < 0.001 ***
#  Continuous primary - Continuous logged == 0   14.100     17.534   0.804  0.84536    
#  Oil palm - Continuous logged == 0            -82.741     14.261  -5.802  < 0.001 ***
#  Oil palm - Continuous primary == 0           -96.841     14.261  -6.791  < 0.001 ***








### INCLUDING TREES, PALMS, DEADWOOD AND LIANAS: IN SUPP INFO ###
# i.e. total AGC estimates

#  uninformative prior for random effect sd
plot_c_lme_all <- blmer(Total_carbon_Mgha ~ Forest_type +
                         (1|Site_code), # random intercept
                       data = plot_carbon_op, 
                       REML=FALSE,
                       cov.prior = gamma(shape = 2.5, rate = 0), 
                       control = lmerControl(optimizer ="Nelder_Mead"))

summary(plot_c_lme_all)
# random effect SD is 9.10

anova(plot_c_lme_all)

drop1(plot_c_lme_all, test="Chisq") # likelihood ratio test against random effect-only model
#             Df    AIC    LRT   Pr(Chi)    
#<none>         614.13                     
#Forest_type  3 653.11 44.987 9.314e-10 ***


# normality of random effect
hist(unlist(ranef(plot_c_lme_all)$Site_code), col="grey")

# spread of residuals
plot(plot_c_lme_all) 

# QQ plot to check normality of residuals
qqnorm(resid(plot_c_lme_all))


#### post-hoc test: pairwise difference p vals
plot_c_lme_tukey_all <- glht(plot_c_lme_all, mcp(Forest_type = "Tukey")) 
summary(plot_c_lme_tukey_all)


#Estimate Std. Error z value Pr(>|z|)    
#  Continuous logged - HCV == 0                  47.862     13.071   3.662  0.00129 ** 
#  Continuous primary - HCV == 0                 79.454     13.071   6.079  < 0.001 ***
#  Oil palm - HCV == 0                          -35.885      8.442  -4.251  < 0.001 ***
#  Continuous primary - Continuous logged == 0   31.592     17.180   1.839  0.24328    
#  Oil palm - Continuous logged == 0            -83.747     13.984  -5.989  < 0.001 ***
#  Oil palm - Continuous primary == 0          -115.339     13.984  -8.248  < 0.001 ***







#### how much variation does liana and CWD carbon explain? ####

plot_carbon$CWD_liana_carbon_Mgha <- plot_carbon$CWD_carbon_Mgha + plot_carbon$Liana_carbon_Mgha

CWD_liana_lme <- lmer(Total_carbon_Mgha ~ CWD_liana_carbon_Mgha +
                   (1|Site_code), # random intercept
                 data = plot_carbon,
                 REML = FALSE) # for comparison with null model

summary(CWD_liana_lme)

plot(CWD_liana_lme) # variance is lower at higher values 

# QQ plot to check normality of residuals - fixed effect
qqnorm(resid(CWD_liana_lme))

# QQ plot to check random effects
qqnorm(ranef(CWD_liana_lme)$Site_code[,1])
# normal



# piecewiseSEM package gives pseudo-r-squared for mixed models

# marginal r2 is the proportion of variance explained by the fixed
# variables alone: fixed effects variance, divided by total variance explained
# by the model


rsquared(CWD_liana_lme)
#           Response   family     link method   Marginal Conditional
#  Total_carbon_Mgha gaussian identity   none 0.06320766   0.4874934





#### get estimates and CIs for each landuse type ####



lu_pred <- effect(term = "Forest_type",
                  mod = plot_c_lme,
                  se = TRUE) # gives 95% CIs by default

lu_CI <- cbind(lu_pred$x,
               lu_pred$fit,
               lu_pred$lower,
               lu_pred$upper)# this should be in correct order to match the categories
colnames(lu_CI)[2] <- "mean_AGC"
colnames(lu_CI)[3] <- "lower"
colnames(lu_CI)[4] <- "upper"

 lu_CI
#         Forest_type  mean_AGC     lower     upper
# 1                HCV  52.80476  43.53986  62.06967
# 2  Continuous logged 100.64769  77.35895 123.93643
# 3 Continuous primary 126.44134 103.15260 149.73008
# 4           Oil palm  30.33500  16.89135  43.77865





######## for other tree height models ##############

#### get estimates and CIs for each landuse type ####

lu_pred <- effect(term = "Forest_type",
                  mod = plot_c_lme,
                  se = TRUE) # gives 95% CIs by default

lu_CI <- cbind(lu_pred$x,
               lu_pred$fit,
               lu_pred$lower,
               lu_pred$upper)# this should be in correct order to match the categories
colnames(lu_CI)[2] <- "mean_AGC"
colnames(lu_CI)[3] <- "lower"
colnames(lu_CI)[4] <- "upper"

lu_CI



lu_pred_chave <- effect(term = "Forest_type",
                  mod = plot_c_lme_chave,
                  se = TRUE) # gives 95% CIs by default

lu_CI_chave <- cbind(lu_pred_chave$x,
               lu_pred_chave$fit,
               lu_pred_chave$lower,
               lu_pred_chave$upper)# this should be in correct order to match the categories
colnames(lu_CI_chave)[2] <- "mean_AGC"
colnames(lu_CI_chave)[3] <- "lower"
colnames(lu_CI_chave)[4] <- "upper"

 lu_CI_chave
#         Forest_type  mean_AGC    lower     upper
# 1                HCV  69.12317 59.37340  78.87294
# 2  Continuous logged 103.39355 78.78568 128.00142
# 3 Continuous primary 117.01835 92.41048 141.62622
# 4           Oil palm  30.33500 16.56995  44.10005




#### Feldpausch et al model (regional, SE Asia)


#### get estimates and CIs for each landuse type ####


lu_pred_feldpausch <- effect(term = "Forest_type",
                        mod = plot_c_lme_feldpausch,
                        se = TRUE) # gives 95% CIs by default

lu_CI_feldpausch <- cbind(lu_pred_feldpausch$x,
                     lu_pred_feldpausch$fit,
                     lu_pred_feldpausch$lower,
                     lu_pred_feldpausch$upper)# this should be in correct order to match the categories
colnames(lu_CI_feldpausch)[2] <- "mean_AGC"
colnames(lu_CI_feldpausch)[3] <- "lower"
colnames(lu_CI_feldpausch)[4] <- "upper"

lu_CI_feldpausch
#         Forest_type  mean_AGC     lower     upper
#1                HCV  68.41915  58.57274  78.26555
#2  Continuous logged 113.07605  88.27500 137.87710
#3 Continuous primary 127.17555 102.37450 151.97660
#4           Oil palm  30.33500  16.24104  44.42896



##### for total AGC incl. lianas and CWD #####

lu_pred_all <- effect(term = "Forest_type",
                             mod = plot_c_lme_all,
                             se = TRUE) # gives 95% CIs by default

lu_CI_all <- cbind(lu_pred_all$x,
                     lu_pred_all$fit,
                     lu_pred_all$lower,
                     lu_pred_all$upper)# this should be in correct order to match the categories
colnames(lu_CI_all)[2] <- "mean_AGC"
colnames(lu_CI_all)[3] <- "lower"
colnames(lu_CI_all)[4] <- "upper"

lu_CI_all
#         Forest_type  mean_AGC     lower     upper
#1                HCV  68.41915  58.57274  78.26555
#2  Continuous logged 113.07605  88.27500 137.87710
#3 Continuous primary 127.17555 102.37450 151.97660
#4           Oil palm  30.33500  16.24104  44.42896




##### FIGURE 2 #######


##### Plot points (mean) with SE and show plots in background ####

# factor levels in desired order
plot_carbon_op$Forest_type <- factor(plot_carbon_op$Forest_type,
                                     levels = c("Oil palm",
                                                "HCV",
                                                "Continuous logged",
                                                "Continuous primary"))




# make a new colour palette with OP too
forest_type_col_OP <- c("Oil palm" = "#DEA02C",
                        "HCV" = "#8F8F8F", 
                        "Continuous logged" = "#88cd66",
                        "Continuous primary" = "#095E06")

forest_type_shape <- c("Oil palm" = 1,
                       "HCV" = 16, 
                       "Continuous logged" = 16,
                       "Continuous primary" = 16)



ggplot()+
  geom_jitter(data = plot_carbon_op,
              aes(x = Forest_type, 
                  y = Tree_palm_carbon_Mgha,
                  colour = Forest_type,
                  shape = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = lu_CI,
                aes(x = Forest_type,
                    ymin = lower,
                    ymax = upper),
                # shows 95% CIs
                width = 0.15,
                size = 0.8)+
  geom_point(data = lu_CI,
             aes(x = Forest_type,
                 y = mean_AGC),
             size = 3,
             shape = 21,
             fill = "white") +
  scale_colour_manual(values = forest_type_col_OP)+
  scale_shape_manual(values = forest_type_shape)+
  xlab("Land-use") +
  ylab(bquote("AGC in plot/Mg ha"^-1*"")) +
  scale_y_continuous(limits = c(0,240), expand = c(0,0)) +
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Oil palm",
                                   "Set-aside",
                                   "Logged forest",
                                   "Primary forest")))+
  geom_text(aes(label = c("A", "B", "C", "C"),
                x = c(1,2,3,4),
                y = 232))+
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_blank(),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(1,1,2,1), "lines"))







##### SUPP FIGURE: comparison of AGC by tree height methods ######
# 6 grid plot: firstly, two-way correlations between the methods
# secondly, the three sets of land-use AGC estimates 

# run fig 2 again with specified y axis for comparing methods of tree height
lu_a <- ggplot()+
  geom_jitter(data = plot_carbon_op,
              aes(x = Forest_type, 
                  y = Tree_palm_carbon_Mgha,
                  colour = Forest_type,
                  shape = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = lu_CI,
                aes(x = Forest_type,
                    ymin = lower,
                    ymax = upper),
                # shows 95% CIs
                width = 0.15,
                size = 0.8)+
  geom_point(data = lu_CI,
             aes(x = Forest_type,
                 y = mean_AGC),
             size = 3,
             shape = 21,
             fill = "white") +
  scale_colour_manual(values = forest_type_col_OP)+
  scale_shape_manual(values = forest_type_shape)+
  xlab("Land-use") +
  ylab(bquote("AGC in plot/Mg ha"^-1*" (log-log model)")) +
  scale_y_continuous(limits = c(0,240), expand = c(0,0)) +
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Oil palm",
                                   "Set-aside",
                                   "Logged forest",
                                   "Primary forest")))+
  geom_text(aes(label = c("A", "B", "C", "C"),
                x = c(1,2,3,4),
                y = 232))+
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_blank(),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(1,1,2,1), "lines"))



lu_b <- ggplot()+
  geom_jitter(data = plot_carbon_op,
              aes(x = Forest_type, 
                  y = Tree_palm_carbon_chaveE_Mgha,
                  colour = Forest_type,
                  shape = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = lu_CI_chave,
                aes(x = Forest_type,
                    ymin = lower,
                    ymax = upper),
                # shows 95% CIs
                width = 0.15,
                size = 0.8)+
  geom_point(data = lu_CI_chave,
             aes(x = Forest_type,
                 y = mean_AGC),
             size = 3,
             shape = 21,
             fill = "white") +
  scale_colour_manual(values = forest_type_col_OP)+
  scale_shape_manual(values = forest_type_shape)+
  xlab("Land-use") +
  ylab(bquote("AGC in plot/Mg ha"^-1*" (climatic model)")) +
  scale_y_continuous(limits = c(0,240), expand = c(0,0)) +
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Oil palm",
                                   "Set-aside",
                                   "Logged forest",
                                   "Primary forest")))+
  geom_text(aes(label = c("A", "B", "C", "C"),
                x = c(1,2,3,4),
                y = 232))+
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_blank(),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(1,1,2,1), "lines"))


lu_c <- ggplot()+
  geom_jitter(data = plot_carbon_op,
              aes(x = Forest_type, 
                  y = Tree_palm_carbon_feldpausch_Mgha,
                  colour = Forest_type,
                  shape = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = lu_CI_feldpausch,
                aes(x = Forest_type,
                    ymin = lower,
                    ymax = upper),
                # shows 95% CIs
                width = 0.15,
                size = 0.8)+
  geom_point(data = lu_CI_feldpausch,
             aes(x = Forest_type,
                 y = mean_AGC),
             size = 3,
             shape = 21,
             fill = "white") +
  scale_colour_manual(values = forest_type_col_OP)+
  scale_shape_manual(values = forest_type_shape)+
  xlab("Land-use") +
  ylab(bquote("AGC in plot/Mg ha"^-1*" (regional model)")) +
  scale_y_continuous(limits = c(0,240), expand = c(0,0)) +
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Oil palm",
                                   "Set-aside",
                                   "Logged forest",
                                   "Primary forest")))+
  geom_text(aes(label = c("A", "B", "C", "C"),
                x = c(1,2,3,4),
                y = 232))+
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_blank(),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(1,1,2,1), "lines"))




# extract the legend from one of the plots
legend <- get_legend(
  # create some space to the left of the legend
  comp_a)

comp <- plot_grid(comp_a + theme(legend.position="none"), 
          comp_b + theme(legend.position="none"), 
          comp_c + theme(legend.position = "none"),
          labels = c("(a)", "(b)", "(c)"), 
          nrow = 1,
          label_size = 10)
          
lu <- plot_grid(lu_a,
          lu_b,
          lu_c,
          labels= c("(d)", "(e)", "(f)"),
          nrow = 1,
          label_size = 10)



plot_grid(legend, comp, lu, nrow = 3,
          rel_heights = c(0.1,1,1))



### SUPP FIGURE: TOTAL C STOCKS ###

ggplot()+
  geom_jitter(data = plot_carbon_op,
              aes(x = Forest_type, 
                  y = Total_carbon_Mgha,
                  colour = Forest_type,
                  shape = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = lu_CI_all,
                aes(x = Forest_type,
                    ymin = lower,
                    ymax = upper),
                # shows 95% CIs
                width = 0.15,
                size = 0.8)+
  geom_point(data = lu_CI_all,
             aes(x = Forest_type,
                 y = mean_AGC),
             size = 3,
             shape = 21,
             fill = "white") +
  scale_colour_manual(values = forest_type_col_OP)+
  scale_shape_manual(values = forest_type_shape)+
  xlab("Land-use") +
  ylab(bquote("AGC in plot/Mg ha"^-1*"")) +
  scale_y_continuous(limits = c(0,240), expand = c(0,0)) +
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Oil palm",
                                   "Set-aside",
                                   "Logged forest",
                                   "Primary forest")))+
  geom_text(aes(label = c("A", "B", "C", "C"),
                x = c(1,2,3,4),
                y = 232))+
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_blank(),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(1,1,2,1), "lines"))





########### SITE-LEVEL VARIATION IN C STOCKS ########

# write another variable to order the sites by

# also get labels for the sample sizes
plot_carbon2 <- plot_carbon %>% 
  group_by(Site_code) %>% mutate(n = n()) %>% 
  mutate(label = paste0(Site_code,'\nN=',n))

plot_carbon2$label <- as.factor(plot_carbon2$label)


plot_carbon2$label <- factor(plot_carbon2$label,
                                     levels = c("F6\nN=2",
                                                "F7\nN=2",
                                               "F9\nN=2",
                                               "F13\nN=2",
                                               "F15\nN=2",
                                               "F2\nN=3",
                                               "F3\nN=3",
                                               "F5\nN=3",
                                               "F8\nN=3",
                                               "F10\nN=3",
                                               "F11\nN=3",
                                               "F12\nN=3",
                                               "F14\nN=3",
                                               "F16\nN=3" ,
                                               "F17\nN=3",
                                               "F18\nN=3",
                                               "F1\nN=3" ,
                                               "F4\nN=3"))
                                               
                                               
# write dataset with blanks for sites with 2 plots to avoid doing boxplots for these
plot_carbon3 <- plot_carbon2            

plots2 <- c("F6", "F7", "F9", "F13", "F15")
                                
plot_carbon3[plot_carbon3$Site_code %in% plots2,]$Tree_palm_carbon_Mgha <- NA




ggplot(data = plot_carbon2,
       aes(x = label,
           y = Tree_palm_carbon_Mgha,
           colour = Forest_type))+
  geom_boxplot(data = plot_carbon3,
               aes(x = label,
                   y = Tree_palm_carbon_Mgha,
                   colour = Forest_type))+
  geom_jitter(width = 0.2)+
  scale_colour_manual(values = forest_type_col_OP,
                      name = "Forest type",
                      labels = c("Set-aside",
                                 "Continuous logged",
                                 "Continuous primary"))+
  xlab("Site") +
  ylab(bquote("AGC in plot/Mg ha"^-1*"")) +
  scale_y_continuous(limits = c(0,240), expand = c(0,0)) +
  theme_classic()+
  theme(legend.position = "right",
        panel.grid.major.x = element_line(colour = "lightgrey"),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(1,1,2,1), "lines"))








############ RESULTS 2 CHANGES IN VEGETATION STRUCTURE #############


######## How do size, stem density and wood density of the four size classes #################
# vary by forest type? 


### trees, saplings, seedlings; palms are included in medium & large trees - none in the smaller classes
# mean wd does not include palms



######## reorganise data to long format for veg structure measures ############


mean_dbh <- gather(dplyr::select(plot_carbon,
                                 Site_plot_code,
                                 Mean_dbh_sapling_cm,
                                 Mean_dbh_smalltree_cm,
                                 Mean_dbh_medlargetree_cm),
                   Mean_dbh_sapling_cm,
                   Mean_dbh_smalltree_cm,
                   Mean_dbh_medlargetree_cm,
                   key = "Size_class",
                   value = "mean_dbh")

mean_dbh$Size_class <- gsub("_cm",
                            "",
                            gsub("Mean_dbh_",
                                 "",
                                 mean_dbh$Size_class))




mean_wd <- gather(dplyr::select(plot_carbon,
                                Site_plot_code,
                                Mean_wd_seedling_gcm3,
                                Mean_wd_sapling_gcm3,
                                Mean_wd_smalltree_gcm3,
                                Mean_wd_medlargetree_gcm3),
                  Mean_wd_seedling_gcm3,
                  Mean_wd_sapling_gcm3,
                  Mean_wd_smalltree_gcm3,
                  Mean_wd_medlargetree_gcm3,
                  key = "Size_class",
                  value = "mean_wd")

mean_wd$Size_class <- gsub("_gcm3",
                           "",
                           gsub("Mean_wd_",
                                "",
                                mean_wd$Size_class))




stem_nha <- gather(dplyr::select(plot_carbon,
                                Site_plot_code,
                                Site_code,
                                Stem_nha_seedling,
                                Stem_nha_sapling,
                                Stem_nha_smalltree,
                                Stem_nha_medlargetree),
                   Stem_nha_seedling,
                   Stem_nha_sapling,
                   Stem_nha_smalltree,
                   Stem_nha_medlargetree,
                  key = "Size_class",
                  value = "stem_nha")

stem_nha$Size_class <- gsub("Stem_nha_",
                           "",
                           stem_nha$Size_class)



### join together into single dataframe ####
veg_summary <- left_join(stem_nha,
                         mean_dbh,
                         by = c("Site_plot_code",
                                "Size_class")) %>%
  left_join(mean_wd,
            by = c("Site_plot_code",
                   "Size_class"))


# join forest type for models
veg_summary <- left_join(veg_summary,
                         dplyr::select(plot_carbon,
                                       Site_plot_code,
                                       Forest_type),
                         by = "Site_plot_code")










############# MODELS: forest type on veg structure ##############


########### WOOD DENSITY #########

wd_blme <- blmer(mean_wd ~ Forest_type* Size_class + # fixed effects
                   # want to include interaction so that wd can vary differently
                   # between forest types for each size class
                   (1|Site_code), # random intercept
                 data = veg_summary,
                 REML = FALSE,
                 # uninformative prior for REs
                 cov.prior = gamma(shape = 2.5, rate = 0),
                 control = lmerControl(optimizer ="Nelder_Mead"))

summary(wd_blme)

hist(unlist(ranef(wd_blme)$Site_code), col="grey")
plot(wd_blme)
qqnorm(resid(wd_blme))

anova(wd_blme)

drop1(wd_blme, test="Chisq")
# mean_wd ~ Forest_type * Size_class + (1 | Site_code)
#                       Df     AIC    LRT Pr(Chi)
#<none>                    -604.66               
#Forest_type:Size_class  6 -611.27 5.3807   0.496

### need to remove interaction term from model


wd_blme2 <- blmer(mean_wd ~ Forest_type + Size_class + # fixed effects
                    (1|Site_code), # random intercept
                  data = veg_summary,
                  REML = FALSE,
                  # uninformative prior for REs
                  cov.prior = gamma(shape = 2.5, rate = 0),
                  control = lmerControl(optimizer ="Nelder_Mead"))

drop1(wd_blme2, test = "Chisq")
#mean_wd ~ Forest_type + Size_class + (1 | Site_code)
#            Df     AIC    LRT   Pr(Chi)    
#<none>         -611.27                     
#Forest_type  2 -614.66  0.617    0.7347    
#Size_class   3 -576.06 41.212 5.895e-09 ***


## remove forest type

wd_blme3 <- blmer(mean_wd ~  Size_class + # fixed effects
                    (1|Site_code), # random intercept
                  data = veg_summary,
                  REML = FALSE,
                  # uninformative prior for REs
                  cov.prior = gamma(shape = 2.5, rate = 0),
                  control = lmerControl(optimizer ="Nelder_Mead"))

drop1(wd_blme3, test = "Chisq")
#mean_wd ~ Size_class + (1 | Site_code)
#            Df     AIC    LRT   Pr(Chi)    
#<none>        -614.66                     
#Size_class  3 -579.45 41.205 5.917e-09 ***



wd_pred <- effect(term = "Size_class",
                  mod = wd_blme3,
                  se = TRUE) # gives 95% CIs by default

wd_CI <- cbind(wd_pred$x,
               wd_pred$fit,
               wd_pred$lower,
               wd_pred$upper)# this should be in correct order to match the categories
colnames(wd_CI)[2] <- "mean_wd"
colnames(wd_CI)[3] <- "lower"
colnames(wd_CI)[4] <- "upper"










########### MEAN DBH #########

# exclude seedlings
# need to log the dbh to avoid residuals increasing with dbh

veg_summary_dbh <- filter(veg_summary, Size_class != "seedling") %>%
  mutate(mean_dbh_log = log(mean_dbh))


dbh_blme <- blmer(mean_dbh_log ~ Forest_type* Size_class+
                  (1|Site_code), # random intercept
                data = veg_summary_dbh,
                REML = FALSE,
                # uninformative prior for REs
                cov.prior = gamma(shape = 2.5, rate = 0),
                control = lmerControl(optimizer ="Nelder_Mead"))



summary(dbh_blme)

hist(unlist(ranef(dbh_blme)$Site_code), col="grey")
plot(dbh_blme)
qqnorm(resid(dbh_blme))


anova(dbh_blme)

drop1(dbh_blme, test="Chisq") # likelihood ratio test against random effect-only model
#mean_dbh_log ~ Forest_type * Size_class + (1 | Site_code)
                        #Df     AIC    LRT   Pr(Chi)    
#<none>                    -247.35                     
#Forest_type:Size_class  4 -210.26 45.094 3.801e-09 ***


# keep interaction. get final model p value in comparison to no fixed effects
dbh_blme_null <- blmer(mean_dbh_log ~ 1+
                         (1|Site_code), # random intercept
                       data = veg_summary_dbh,
                       REML = FALSE,
                       # uninformative prior for REs
                       cov.prior = gamma(shape = 2.5, rate = 0),
                       control = lmerControl(optimizer ="Nelder_Mead"))


anova(dbh_blme, dbh_blme_null)
#  dbh_blme_null: mean_dbh_log ~ 1 + (1 | Site_code)
#dbh_blme: mean_dbh_log ~ Forest_type * Size_class + (1 | Site_code)
#               Df     AIC     BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)    
#dbh_blme_null  3  391.14  400.09 -192.57   385.14                             
#dbh_blme      11 -247.35 -214.53  134.68  -269.35 654.49      8  < 2.2e-16 ***




#### Get Tukey posthoc test results to see which differences are significant ####

### the glht function I used earlier can't do interactions

# So I need to recode the two fixed effects into a single categorical predictor,
# where each level is a different combination of tree size and forest type
# see Callum's paper https://esajournals.onlinelibrary.wiley.com/doi/full/10.1002/ecs2.2550 

veg_summary_dbh <-  unite(veg_summary_dbh,
                          col = "Size_for",
                          c("Size_class", "Forest_type"),
                          remove = FALSE)# keep the original factors too

veg_summary_dbh$Size_for <- factor(veg_summary_dbh$Size_for)

dbh_blme_ph <-  blmer(mean_dbh_log ~ Size_for +
                        (1|Site_code), # random intercept
                      data = veg_summary_dbh,
                      REML = FALSE,
                      # uninformative prior for REs
                      cov.prior = gamma(shape = 2.5, rate = 0),
                      control = lmerControl(optimizer ="Nelder_Mead"))

summary(dbh_blme_ph)

dbh_blme_tukey <- glht(dbh_blme_ph, mcp(Size_for = "Tukey")) 

summary(dbh_blme_tukey)
#                                                                    Estimate Std. Error z value Pr(>|z|)    
#Large tree_Continuous primary - Large tree_Continuous logged == 0    0.15644    0.05867   2.666  0.14308    
#Large tree_HCV - Large tree_Continuous logged == 0                  -0.18427    0.04475  -4.117  0.00123 ** 
#Large tree_HCV - Large tree_Continuous primary == 0                 -0.34071    0.04475  -7.613  < 0.001 ***
#Medium tree_Continuous primary - Medium tree_Continuous logged == 0  0.05158    0.05867   0.879  0.99284    
#Medium tree_HCV - Medium tree_Continuous logged == 0                 0.02993    0.04468   0.670  0.99893    
#Medium tree_HCV - Medium tree_Continuous primary == 0               -0.02165    0.04468  -0.485  0.99990    
#Sapling_Continuous primary - Sapling_Continuous logged == 0          0.13230    0.05867   2.255  0.33946    
#Sapling_HCV - Sapling_Continuous logged == 0                         0.09016    0.04468   2.018  0.49795    
#Sapling_HCV - Sapling_Continuous primary == 0                       -0.04214    0.04468  -0.943  0.98856    




dbh_pred <- effect(term = "Forest_type:Size_class",
                  mod = dbh_blme,
                  se = TRUE) # gives 95% CIs by default

dbh_CI <- cbind(dbh_pred$x,
                dbh_pred$fit,
                dbh_pred$lower,
                dbh_pred$upper)# this should be in correct order to match the categories
colnames(dbh_CI)[3] <- "mean_dbh"
colnames(dbh_CI)[4] <- "lower"
colnames(dbh_CI)[5] <- "upper"


# view back-transformed values
cbind(dbh_CI[,1:2], exp(dbh_CI[,3:5]))
#          Forest_type   Size_class  mean_dbh     lower     upper
#1                HCV medlargetree 34.673207 33.540984 35.843650
#2  Continuous logged medlargetree 41.689037 38.405544 45.253253
#3 Continuous primary medlargetree 48.748467 44.908962 52.916231
#4                HCV      sapling  4.245755  4.108750  4.387328
#5  Continuous logged      sapling  3.879714  3.574142  4.211411
#6 Continuous primary      sapling  4.428504  4.079708  4.807120
#7                HCV    smalltree 15.663652 15.158206 16.185951
#8  Continuous logged    smalltree 15.201856 14.004534 16.501543
#9 Continuous primary    smalltree 16.006538 14.745838 17.375022







########### STEM DENSITY #########


# need to log the stem_nha to avoid residuals increasing with dbh

# log (n+1) because of the 0 value

veg_summary <- mutate(veg_summary,
                      stem_nha_log1 = log(stem_nha + 1))

stem_blme <- blmer(stem_nha_log1 ~ Forest_type* Size_class+
                     (1|Site_code), # random intercept
                   data = veg_summary,
                   REML = FALSE,
                   # uninformative prior for REs
                   cov.prior = gamma(shape = 2.5, rate = 0),
                   control = lmerControl(optimizer ="Nelder_Mead"))


summary(stem_blme)

hist(unlist(ranef(stem_blme)$Site_code), col="grey")
plot(stem_blme)
qqnorm(resid(stem_blme))


anova(stem_blme)


drop1(stem_blme, test="Chisq") # likelihood ratio test against random effect-only model
#stem_nha_log1 ~ Forest_type * Size_class + (1 | Site_code)
#                       Df    AIC    LRT  Pr(Chi)    
#<none>                    334.29                    
#Forest_type:Size_class  6 359.93 37.641 1.32e-06 ***


# keep interaction. get final model p value in comparison to no fixed effects
stem_blme_null <- blmer(stem_nha_log1 ~ 1 +
                          (1|Site_code), # random intercept
                        data = veg_summary,
                        REML = FALSE,
                        # uninformative prior for REs
                        cov.prior = gamma(shape = 2.5, rate = 0),
                        control = lmerControl(optimizer ="Nelder_Mead"))


anova(stem_blme, stem_blme_null)
#stem_blme_null: stem_nha_log1 ~ 1 + (1 | Site_code)
#stem_blme: stem_nha_log1 ~ Forest_type * Size_class + (1 | Site_code)
#                Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)    
#stem_blme_null  3 876.81 886.65 -435.41   870.81                             
#stem_blme      14 334.29 380.18 -153.15   306.29 564.52     11  < 2.2e-16 ***






#### Get Tukey posthoc test results to see which differences are significant ####

veg_summary_stem <-  unite(veg_summary,
                          col = "Size_for",
                          c("Size_class", "Forest_type"),
                          remove = FALSE)# keep the original factors too

veg_summary_stem$Size_for <- factor(veg_summary_stem$Size_for)

stem_blme_ph <-  blmer(stem_nha_log1 ~ Size_for +
                        (1|Site_code), # random intercept
                      data = veg_summary_stem,
                      REML = FALSE,
                      # uninformative prior for REs
                      cov.prior = gamma(shape = 2.5, rate = 0),
                      control = lmerControl(optimizer ="Nelder_Mead"))

summary(stem_blme_ph)

stem_blme_tukey <- glht(stem_blme_ph, mcp(Size_for = "Tukey")) 

summary(stem_blme_tukey)

#Linear Hypotheses:
#                                                                Estimate Std. Error z value Pr(>|z|)    
#medlargetree_Continuous primary - medlargetree_Continuous logged == 0 -0.35477    0.37036  -0.958   0.9979     
#medlargetree_HCV - medlargetree_Continuous logged == 0                -0.54233    0.28147  -1.927   0.7001      
#medlargetree_HCV - medlargetree_Continuous primary == 0               -0.18757    0.28147  -0.666   0.9999     

#smalltree_Continuous primary - smalltree_Continuous logged == 0     -0.37681    0.37036  -1.017   0.9963    
#smalltree_HCV - smalltree_Continuous logged == 0                     0.23078    0.28147   0.820   0.9995   
#smalltree_HCV - smalltree_Continuous primary == 0                    0.60758    0.28147   2.159   0.5299    

#sapling_Continuous primary - sapling_Continuous logged == 0      0.02064    0.37036   0.056   1.0000    
#Sapling_HCV - Sapling_Continuous logged == 0                    -0.19755    0.23510  -0.840   0.9994    
#sapling_HCV - sapling_Continuous primary == 0                   -0.21596    0.28147  -0.767   0.9997       

#seedling_Continuous primary - seedling_Continuous logged == 0    0.66576    0.37036   1.798   0.7841    
#seedling_HCV - seedling_Continuous logged == 0                  -0.60537    0.28147  -2.151   0.5359      
#seedling_HCV - seedling_Continuous primary == 0                 -1.27113    0.28147  -4.516    <0.01 ***





stem_pred <- effect(term = "Forest_type:Size_class",
                   mod = stem_blme,
                   se = TRUE) # gives 95% CIs by default

stem_CI <- cbind(stem_pred$x,
                 stem_pred$fit,
                 stem_pred$lower,
                 stem_pred$upper)# this should be in correct order to match the categories
colnames(stem_CI)[3] <- "stem_nha"
colnames(stem_CI)[4] <- "lower"
colnames(stem_CI)[5] <- "upper"


# view back-transformed values
cbind(stem_CI[,1:2], (exp(stem_CI[,3:5]) - 1))

# divide by 10000 to get density per m2 (currently per ha)

#          Forest_type Size_class    stem_nha       lower       upper
#1                 HCV  medlargetree    64.48701    52.42563    79.27137
#2   Continuous logged  medlargetree   111.63884    66.18911   187.83279
#3  Continuous primary  medlargetree    77.99771    46.12217   131.43530
#4                 HCV    smalltree   335.48117   273.50817   411.44520
#5   Continuous logged    smalltree   266.13836   158.34814   446.84271
#6  Continuous primary    smalltree   182.27014   108.32071   306.24227
#7                 HCV    sapling  2288.28235  1866.64303  2805.11100
#8   Continuous logged    sapling  2782.08632  1659.11214  4664.69052
#9  Continuous primary    sapling  2840.12092  1693.72980  4761.98231
#10                HCV   seedling 16352.26425 13340.32510 20044.17914
#11  Continuous logged   seedling 29957.00886 17868.96467 50221.94734
#12 Continuous primary   seedling 58296.36563 34773.40271 97731.31385






####### SUPPLEMENTARY FIGURE: DIFFERENCES IN VEG STRUCTURE ##########

###### Plot 12 facets separately and bring together ####

# extend wd_CI to include forest type (non-sig so repeat predictions by size class)

wd_CI <- rbind(wd_CI,
               wd_CI,
               wd_CI)
wd_CI$Forest_type <- c(rep("HCV", 4),
                       rep("Continuous logged", 4),
                       rep("Continuous primary", 4))


# rows: stem density, mean dbh, wood density
# columns: seedlings, saplings, medium trees, large trees


# create blank seedling graph to keep alignment 4 graphs in a row
dbh_seed <- ggplot(data = filter(veg_summary, Size_class == "seedling"),
       aes(x = Forest_type,
           y = mean_dbh))+
  geom_jitter(aes(colour = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = filter(dbh_CI, Size_class == "seedling"),
                aes(x = Forest_type,
                    ymin = exp(lower),
                    ymax = exp(upper),
                    y = exp(mean_dbh)), # gives odd error if this isn't here
                width = 0.15,
                size = 0.8)+
  geom_point(data = filter(dbh_CI, Size_class == "seedling"),
             aes(x = Forest_type,
                 y = exp(mean_dbh)),
             size = 3,
             shape = 21,
             fill = "white") +
  theme_classic()+  
  scale_colour_manual(values = forest_type_col)+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "none",
        strip.background = element_blank(),
        strip.text = element_blank(),# removes facet labels
        legend.background = element_rect(colour = "black"),
        axis.title.x=element_blank(),
  plot.title = element_text(hjust = 0.5, size = 11))+
  ggtitle("Seedlings") + # title for all in the column
  ylab("Mean dbh/cm") +
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Set- aside",
                                   "Logged forest",
                                   "Primary forest")))


dbh_sap <- ggplot(data = filter(veg_summary, Size_class == "sapling"),
                   aes(x = Forest_type,
                       y = mean_dbh))+
  geom_jitter(aes(colour = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = filter(dbh_CI, Size_class == "sapling"),
                aes(x = Forest_type,
                    ymin = exp(lower),
                    ymax = exp(upper),
                    y = exp(mean_dbh)), # gives odd error if this isn't here
                width = 0.15,
                size = 0.8)+
  geom_point(data = filter(dbh_CI, Size_class == "sapling"),
             aes(x = Forest_type,
                 y = exp(mean_dbh)),
             size = 3,
             shape = 21,
             fill = "white") +
  theme_classic()+  
  scale_colour_manual(values = forest_type_col)+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "none",
        strip.background = element_blank(),
        strip.text = element_blank(),# removes facet labels
        legend.background = element_rect(colour = "black"),
        axis.title.y=element_blank(),# turn off y axis title
  axis.title.x=element_blank(),
  plot.title = element_text(hjust = 0.5, size = 11))+
  ggtitle("Saplings") + # title for all in the column
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Set- aside",
                                   "Logged forest",
                                   "Primary forest")))



dbh_mt <- ggplot(data = filter(veg_summary, Size_class == "smalltree"),
                  aes(x = Forest_type,
                      y = mean_dbh))+
  geom_jitter(aes(colour = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = filter(dbh_CI, Size_class == "smalltree"),
                aes(x = Forest_type,
                    ymin = exp(lower),
                    ymax = exp(upper),
                    y = exp(mean_dbh)), # gives odd error if this isn't here
                width = 0.15,
                size = 0.8)+
  geom_point(data = filter(dbh_CI, Size_class == "smalltree"),
             aes(x = Forest_type,
                 y = exp(mean_dbh)),
             size = 3,
             shape = 21,
             fill = "white") +
  theme_classic()+  
  scale_colour_manual(values = forest_type_col)+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "none",
        strip.background = element_blank(),
        strip.text = element_blank(),# removes facet labels
        legend.background = element_rect(colour = "black"),
        axis.title.y=element_blank(),# turn off y axis title
        axis.title.x=element_blank(),
  plot.title = element_text(hjust = 0.5, size = 11))+
  ggtitle("Small trees") + # title for all in the column
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Set- aside",
                                   "Logged forest",
                                   "Primary forest")))


dbh_lt <- ggplot(data = filter(veg_summary, Size_class == "medlargetree"),
                 aes(x = Forest_type,
                     y = mean_dbh))+
  geom_jitter(aes(colour = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = filter(dbh_CI, Size_class == "medlargetree"),
                aes(x = Forest_type,
                    ymin = exp(lower),
                    ymax = exp(upper),
                    y = exp(mean_dbh)), # gives odd error if this isn't here
                width = 0.15,
                size = 0.8)+
  geom_point(data = filter(dbh_CI, Size_class == "medlargetree"),
             aes(x = Forest_type,
                 y = exp(mean_dbh)),
             size = 3,
             shape = 21,
             fill = "white") +
  ggsignif::geom_signif(comparisons = list(c("HCV", "Continuous logged"),
                                           c("HCV", "Continuous primary")),
                        map_signif_level = TRUE,
                        y_position = c(55, 60),
                        annotation = c("**", "***"))+
  scale_y_continuous(limits = c(25,62))+
  theme_classic()+  
  scale_colour_manual(values = forest_type_col)+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "none",
        strip.background = element_blank(),
        strip.text = element_blank(),# removes facet labels
        legend.background = element_rect(colour = "black"),
        axis.title.y=element_blank(),# turn off y axis title
        axis.title.x=element_blank(),
  plot.title = element_text(hjust = 0.5, size = 11))+
  ggtitle("Medium-large trees") + # title for all in the column
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Set- aside",
                                   "Logged forest",
                                   "Primary forest")))

stem_seed <- ggplot(data = filter(veg_summary, Size_class == "seedling"),
                    aes(x = Forest_type,
                        y = stem_nha))+###### still need to change legend
  geom_jitter(aes(colour = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = filter(stem_CI, Size_class == "seedling"),
                aes(x = Forest_type,
                    ymin = (exp(lower) - 1),
                    ymax = (exp(upper) - 1),
                    y = (exp(stem_nha) - 1)),
                width = 0.15,
                size = 0.8)+
  geom_point(data = filter(stem_CI, Size_class == "seedling"),
             aes(x = Forest_type,
                 y = (exp(stem_nha) -1)),
             size = 3,
             shape = 21,
             fill = "white") +
  scale_colour_manual(values = forest_type_col)+
  ggsignif::geom_signif(comparisons = list(c("HCV", "Continuous primary")),
                        map_signif_level = TRUE,
                        y_position = 142000,
                        annotation = "***")+
  theme_classic()+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "none",
        legend.background = element_rect(colour = "black"),
        axis.title.x=element_blank())+
  ylab(bquote("Stem density/n ha"^-1*"")) +
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Set- aside",
                                   "Logged forest",
                                   "Primary forest")))+
  scale_y_continuous(limits = c(0,150000))


stem_sap <- ggplot(data = filter(veg_summary, Size_class == "sapling"),
                    aes(x = Forest_type,
                        y = stem_nha))+###### still need to change legend
  geom_jitter(aes(colour = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = filter(stem_CI, Size_class == "sapling"),
                aes(x = Forest_type,
                    ymin = (exp(lower) - 1),
                    ymax = (exp(upper) - 1),
                    y = (exp(stem_nha) - 1)),
                width = 0.15,
                size = 0.8)+
  geom_point(data = filter(stem_CI, Size_class == "sapling"),
             aes(x = Forest_type,
                 y = (exp(stem_nha)-1)),
             size = 3,
             shape = 21,
             fill = "white") +
  scale_colour_manual(values = forest_type_col)+
  theme_classic()+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "none",
        legend.background = element_rect(colour = "black"),
        plot.title = element_text(hjust = 0.5, size = 11),
        axis.title.x=element_blank(),
        axis.title.y=element_blank())+# turn off y axis title
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Set- aside",
                                   "Logged forest",
                                   "Primary forest")))

stem_mt <- ggplot(data = filter(veg_summary, Size_class == "smalltree"),
                   aes(x = Forest_type,
                       y = stem_nha))+###### still need to change legend
  geom_jitter(aes(colour = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = filter(stem_CI, Size_class == "smalltree"),
                aes(x = Forest_type,
                    ymin = (exp(lower) - 1),
                    ymax = (exp(upper) - 1),
                    y = (exp(stem_nha) - 1)),
                width = 0.15,
                size = 0.8)+
  geom_point(data = filter(stem_CI, Size_class == "smalltree"),
             aes(x = Forest_type,
                 y = (exp(stem_nha)-1)),
             size = 3,
             shape = 21,
             fill = "white") +
  scale_colour_manual(values = forest_type_col)+
  theme_classic()+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "none",
        legend.background = element_rect(colour = "black"),
        plot.title = element_text(hjust = 0.5, size = 11),
        axis.title.x=element_blank(),
        axis.title.y=element_blank())+# turn off y axis title
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Set- aside",
                                   "Logged forest",
                                   "Primary forest")))

stem_lt <- ggplot(data = filter(veg_summary, Size_class == "medlargetree"),
                  aes(x = Forest_type,
                      y = stem_nha))+###### still need to change legend
  geom_jitter(aes(colour = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = filter(stem_CI, Size_class == "medlargetree"),
                aes(x = Forest_type,
                    ymin = (exp(lower) - 1),
                    ymax = (exp(upper) - 1),
                    y = (exp(stem_nha) - 1)),
                width = 0.15,
                size = 0.8)+
  geom_point(data = filter(stem_CI, Size_class == "medlargetree"),
             aes(x = Forest_type,
                 y = (exp(stem_nha)-1)),
             size = 3,
             shape = 21,
             fill = "white") +
  scale_colour_manual(values = forest_type_col)+
  theme_classic()+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "none",
        plot.title = element_text(hjust = 0.5, size = 11),
        legend.background = element_rect(colour = "black"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank())+# turn off y axis title
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Set- aside",
                                   "Logged forest",
                                   "Primary forest")))


wd_seed <- ggplot(data = filter(veg_summary, Size_class == "seedling"),
       aes(x = Forest_type,
           y = mean_wd))+
  geom_jitter(aes(colour = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = filter(wd_CI, Size_class == "seedling"),
                aes(x = Forest_type,
                    ymin = lower,
                    ymax = upper),
                width = 0.15,
                size = 0.8)+
  geom_point(data = filter(wd_CI, Size_class == "seedling"),
             aes(x = Forest_type,
                 y = mean_wd),
             size = 3,
             shape = 21,
             fill = "white") +
  theme_classic()+  
  scale_colour_manual(values = forest_type_col)+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "none",
        legend.background = element_rect(colour = "black"),
        axis.title.x=element_blank())+
  ylab(bquote("Mean wood density/Mg ha"^-1*"")) +
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Set- aside",
                                   "Logged forest",
                                   "Primary forest")))+
  scale_y_continuous(limits = c(0.4,0.7))


wd_sap <- ggplot(data = filter(veg_summary, Size_class == "sapling"),
                  aes(x = Forest_type,
                      y = mean_wd))+
  geom_jitter(aes(colour = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = filter(wd_CI, Size_class == "sapling"),
                aes(x = Forest_type,
                    ymin = lower,
                    ymax = upper),
                width = 0.15,
                size = 0.8)+
  geom_point(data = filter(wd_CI, Size_class == "sapling"),
             aes(x = Forest_type,
                 y = mean_wd),
             size = 3,
             shape = 21,
             fill = "white") +
  theme_classic()+  
  scale_colour_manual(values = forest_type_col)+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "none",
        legend.background = element_rect(colour = "black"),
        axis.title.x=element_blank(),
        axis.title.y = element_blank())+
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Set- aside",
                                   "Logged forest",
                                   "Primary forest")))+
  scale_y_continuous(limits = c(0.4,0.7))



wd_mt <- ggplot(data = filter(veg_summary, Size_class == "smalltree"),
                 aes(x = Forest_type,
                     y = mean_wd))+
  geom_jitter(aes(colour = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = filter(wd_CI, Size_class == "smalltree"),
                aes(x = Forest_type,
                    ymin = lower,
                    ymax = upper),
                width = 0.15,
                size = 0.8)+
  geom_point(data = filter(wd_CI, Size_class == "smalltree"),
             aes(x = Forest_type,
                 y = mean_wd),
             size = 3,
             shape = 21,
             fill = "white") +
  theme_classic()+  
  scale_colour_manual(values = forest_type_col)+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "none",
        legend.background = element_rect(colour = "black"),
        axis.title.x=element_blank(),
        axis.title.y = element_blank())+
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Set- aside",
                                   "Logged forest",
                                   "Primary forest")))+
  scale_y_continuous(limits = c(0.4,0.7))

wd_lt <- ggplot(data = filter(veg_summary, Size_class == "medlargetree"),
                 aes(x = Forest_type,
                     y = mean_wd))+
  geom_jitter(aes(colour = Forest_type),
              width = 0.05,
              height = 0) + 
  geom_errorbar(data = filter(wd_CI, Size_class == "medlargetree"),
                aes(x = Forest_type,
                    ymin = lower,
                    ymax = upper),
                width = 0.15,
                size = 0.8)+
  geom_point(data = filter(wd_CI, Size_class == "medlargetree"),
             aes(x = Forest_type,
                 y = mean_wd),
             size = 3,
             shape = 21,
             fill = "white") +
  theme_classic()+  
  scale_colour_manual(values = forest_type_col)+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        panel.grid.major.x = element_blank(),
        panel.grid.minor.x = element_blank(),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "none",
        legend.background = element_rect(colour = "black"),
        axis.title.x=element_blank(),
        axis.title.y = element_blank())+
  scale_x_discrete(labels = gsub(" ", "\n", # make line breaks at spaces
                                 c("Set- aside",
                                   "Logged forest",
                                   "Primary forest")))+
  scale_y_continuous(limits = c(0.4,0.7))




dbh_seed_grob <- ggplotGrob(dbh_seed)
dbh_sap_grob <- ggplotGrob(dbh_sap)
dbh_mt_grob <- ggplotGrob(dbh_mt)
dbh_lt_grob <- ggplotGrob(dbh_lt)

stem_seed_grob <- ggplotGrob(stem_seed)
stem_sap_grob <- ggplotGrob(stem_sap)
stem_mt_grob <- ggplotGrob(stem_mt)
stem_lt_grob <- ggplotGrob(stem_lt)


wd_seed_grob <- ggplotGrob(wd_seed)
wd_sap_grob <- ggplotGrob(wd_sap)
wd_mt_grob <- ggplotGrob(wd_mt)
wd_lt_grob <- ggplotGrob(wd_lt)


dbh_grob <- cbind(dbh_seed_grob,
                   dbh_sap_grob, 
                   dbh_mt_grob, 
                   dbh_lt_grob,
                   size = "first")

stem_grob <- cbind(stem_seed_grob,
                   stem_sap_grob, 
                   stem_mt_grob, 
                   stem_lt_grob,
                   size = "first")

wd_grob <- cbind(wd_seed_grob,
                   wd_sap_grob, 
                   wd_mt_grob, 
                   wd_lt_grob,
                   size = "first")


grid.newpage()
grid.draw(rbind(stem_grob, dbh_grob, stem_grob, wd_grob, size = "first"))
# repeat stem density plot ensure alignment; later crop



################ RESULTS 3 DRIVERS OF VARIATION IN AGC #################



############# MODELLING DRIVERS OF HCV CARBON VARIATION ############

# Fragmentation PCA

# topography: Slope & Elevation

# Soils - run PCA on measurements





####### LANDSCAPE VARIABLES: FRAGMENTATION #######



######### Fragmentation predictors to test ########

# ForArea_buffer1000m_m2 - forest area within 1km buffer
# Edge_buffer1000 - forest edge within 1km buffer
# Nearest_edge_m
# Years_since_frag - age of fragment in 2017



# for set-asides only

plot_carbon_hcv <- filter(plot_carbon,
                          Forest_type == "HCV")

# convert the forest area into proportion - better for plotting
plot_carbon_hcv <- mutate(plot_carbon_hcv, forest_prop_1km = ForArea_buffer1000m_m2/max(ForArea_buffer1000m_m2))




# test for intercorrelation
cor(plot_carbon_hcv[,c("forest_prop_1km", 
                       "ForEdge_buffer1000m_index", 
                       "Nearest_edge_m", 
                       "Years_since_frag")])



ggpairs(plot_carbon_hcv[,c("forest_prop_1km", 
                           "ForEdge_buffer1000m_index", 
                           "Nearest_edge_m", 
                           "Years_since_frag"),],
        columnLabels = c("Forest area within 1km",
                         "Edge index within 1km",
                         "Nearest edge/m",
                         "Fragment age/years"),
        diag = list(continuous =
                      wrap("barDiag", bins = 8, colour = "black", fill = "lightgrey"),
                    discrete = "barDiag", na = "naDiag"),
        upper = list(continuous = wrap(ggally_cor, color = "black")))+
  theme_bw()



#### also plot boxplots and scatterplots of these metrics and tree AGC ######



box_a <- ggplot()+
  geom_boxplot(data = plot_carbon_hcv,
               aes(y = forest_prop_1km))+
  ylab("Forest area within 1 km")+
  scale_colour_manual(values = forest_type_col_OP)+
  theme_classic()+
  theme(legend.position = "none",
        axis.title.x = element_blank(),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank()) 


box_b <- ggplot()+
  geom_boxplot(data = plot_carbon_hcv,
               aes(y = ForEdge_buffer1000m_index))+
  ylab("Forest edge within 1 km")+
  scale_colour_manual(values = forest_type_col_OP)+
  theme_classic()+
  theme(legend.position = "none",
        axis.title.x = element_blank(),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank()) 

  
box_c <- ggplot()+
  geom_boxplot(data = plot_carbon_hcv,
               aes(y = Nearest_edge_m))+
 ylab("Nearest edge/m")+
  scale_colour_manual(values = forest_type_col_OP)+
  theme_classic()+
  theme(legend.position = "none",
        axis.title.x = element_blank(),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank()) 

  
box_d <- ggplot()+
  geom_boxplot(data = plot_carbon_hcv,
               aes(y = Years_since_frag))+
  ylab("Fragment age/years")+
  scale_colour_manual(values = forest_type_col_OP)+
  theme_classic()+
  theme(legend.position = "none",
        axis.title.x = element_blank(),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank()) 

  
box_e <-  ggplot()+
    geom_point(data = plot_carbon_hcv,
              aes(y = Tree_palm_carbon_Mgha,
                 x = forest_prop_1km,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col_OP)+
  xlab("Forest area within\n1 km (proportion)")+
  ylab(bquote("AGC / Mgha"^-1*""))+   
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_line(colour = "lightgrey"),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"))



box_f <-   ggplot()+
  geom_point(data = plot_carbon_hcv,
             aes(y = Tree_palm_carbon_Mgha,
                 x = ForEdge_buffer1000m_index,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col_OP)+
  xlab("Forest edge within\n1 km (edge index)")+
  ylab(bquote("AGC / Mgha"^-1*""))+   
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_line(colour = "lightgrey"),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"))


box_g <-   ggplot()+
  geom_point(data = plot_carbon_hcv,
             aes(y = Tree_palm_carbon_Mgha,
                 x = Nearest_edge_m,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col_OP)+
  xlab("Nearest edge/m\n")+ # add line after title to align with other plots
  ylab(bquote("AGC / Mgha"^-1*""))+   
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_line(colour = "lightgrey"),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"))


box_h <-   ggplot()+
  geom_point(data = plot_carbon_hcv,
             aes(y = Tree_palm_carbon_Mgha,
                 x = Years_since_frag,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col_OP)+
  xlab("Fragment age/years\n")+ # add line after title to align with other plots
  ylab(bquote("AGC / Mgha"^-1*""))+   
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_line(colour = "lightgrey"),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"))



plot_grid(box_a,
          box_b, 
          box_c, 
          box_d, 
          box_e,
          box_f,
          box_g,
          box_h,
          nrow = 2, 
          labels = c("(a)", "(b)", "(c)", "(d)","(e)","(f)","(g)","(h)"),
          label_size = 10,
          rel_heights = c(1.5,2),
          scale = 0.9)







####### Writing fragmentation PCA ########


frag_pca <- prcomp(plot_carbon_hcv[,c("forest_prop_1km", 
                                       "ForEdge_buffer1000m_index", 
                                       "Nearest_edge_m", 
                                       "Years_since_frag"),],
                   center = TRUE,
                   scale = TRUE)

plot(frag_pca)


summary(frag_pca)

frag_pca
# Importance of components:
#                          PC1    PC2    PC3     PC4
#Standard deviation     1.6495 0.8057 0.6989 0.37626
#Proportion of Variance 0.6802 0.1623 0.1221 0.03539
#Cumulative Proportion  0.6802 0.8425 0.9646 1.00000

#                          PC1        PC2        PC3         PC4
#ForArea_buffer1000m_m2 -0.5668396  0.1859658  0.1869588  0.78048445
#ForEdge_buffer1000m_index      0.5266059 -0.1576789 -0.6134794  0.56698030
#Nearest_edge_m     -0.4149453 -0.8923568 -0.1709877 -0.04778055
#Years_since_frag    0.4787478 -0.3798071  0.7479657  0.25902582

biplot(frag_pca)





autoplot(frag_pca, 
         colour = "#8F8F8F",
         loadings = TRUE,
         loadings.colour = "cadetblue")+ # same colour as tree height points earlier
  theme_classic()+
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        axis.line.x = element_line(colour = "lightgrey"),
        axis.line.y = element_line(colour = "lightgrey"))+
  coord_fixed() + # x and y scales are the same
  geom_vline(aes(xintercept = 0))+
  geom_hline(aes(yintercept = 0))+
  annotate("text",
           label = "Total forest", 
           x = -0.2,
           y = 0.12, colour = "cadetblue")+
  annotate("text",
           label = "area (1 km)", 
           x = -0.2,
           y = 0.09, colour = "cadetblue")+
  annotate("text",
           label = "Forest edge", 
           x = 0.24,
           y = -0.07, colour = "cadetblue")+
  annotate("text",
           label = "index (1 km)", 
           x = 0.24,
           y = -0.1, colour = "cadetblue")+
  annotate("text",
           label = "Distance to", 
           x = -0.15,
           y = -0.33, colour = "cadetblue")+
  annotate("text",
           label = "nearest forest edge", 
           x = -0.15,
           y = -0.36, colour = "cadetblue")+
  annotate("text",
           label = "Years since", 
           x = 0.18,
           y = -0.14, colour = "cadetblue")+
  annotate("text",
           label = "fragmentation", 
           x = 0.18,
           y = -0.17, colour = "cadetblue")




# PC1 explains 68% variation; increasing values represent increasing fragmentation
# longer time since fragmentation, more edgey forest within 1km, less total forest
# within 1km, and a shorter distance to the nearest edge

# to get the values of PC1:
frag_pca$x[,1]

# bind this to plot_carbon_hcv
plot_carbon_hcv$frag_pc1 <- frag_pca$x[,1]





################ Repeating the PCA, with different buffer sizes ################

###### 200m #######


frag_pca200 <- prcomp(plot_carbon_hcv[,c("ForArea_buffer200m_m2", 
                                         "ForEdge_buffer200m_index", 
                                         "Nearest_edge_m", 
                                         "Years_since_frag"),],
                      center = TRUE,
                      scale = TRUE)

summary(frag_pca200)
#                          PC1    PC2     PC3     PC4
#Standard deviation     1.6643 0.9155 0.59650 0.19022
#Proportion of Variance 0.6925 0.2095 0.08895 0.00905
#Cumulative Proportion  0.6925 0.9020 0.99095 1.00000

frag_pca200
#                         PC1          PC2        PC3         PC4
#ForArea_buffer200m_m2  0.5656116 -0.281764824  0.2828926  0.72157043
#ForEdge_buffer200m_index     -0.5648787  0.226231931 -0.3973497  0.68690930
#Nearest_edge_m     0.5171792  0.003898944 -0.8530469 -0.06943639
#Years_since_frag  -0.3058125 -0.932422917 -0.1854613 -0.05167513

biplot(frag_pca200)

# reverse direction to match 1km buffer PCA
plot_carbon_hcv$frag_pc1_200 <- -frag_pca200$x[,1]





###### 500m #######


frag_pca500 <- prcomp(plot_carbon_hcv[,c("ForArea_buffer500m_m2", 
                                         "ForEdge_buffer500m_index", 
                                         "Nearest_edge_m", 
                                         "Years_since_frag"),],
                      center = TRUE,
                      scale = TRUE)

summary(frag_pca500)
#                         PC1    PC2    PC3     PC4
#Standard deviation     1.671 0.8228 0.6677 0.29176
#Proportion of Variance 0.698 0.1692 0.1114 0.02128
#Cumulative Proportion  0.698 0.8673 0.9787 1.00000

frag_pca500
#                         PC1        PC2        PC3         PC4
#ForArea_buffer500m_m2  0.5623340 -0.2523914  0.2422292  0.74926905
#ForEdge_buffer500m_index     -0.5429043  0.1141556 -0.5504662  0.62386723
#Nearest_edge_m     0.4830682 -0.3183857 -0.7866675 -0.21547623
#Years_since_frag  -0.3945637 -0.9065857  0.1395217 -0.05436509

biplot(frag_pca500)

# reverse direction to match 1km buffer PCA
plot_carbon_hcv$frag_pc1_500 <- -frag_pca500$x[,1]





###### 1500m #######


frag_pca1500 <- prcomp(plot_carbon_hcv[,c("ForArea_buffer1500m_m2", 
                                          "ForEdge_buffer1500m_index", 
                                          "Nearest_edge_m", 
                                          "Years_since_frag"),],
                       center = TRUE,
                       scale = TRUE)

summary(frag_pca1500)
#                          PC1    PC2    PC3     PC4
#Standard deviation     1.6156 0.8529 0.6906 0.43067
#Proportion of Variance 0.6525 0.1819 0.1192 0.04637
#Cumulative Proportion  0.6525 0.8344 0.9536 1.00000

frag_pca1500
#                         PC1        PC2         PC3        PC4
#ForArea_buffer1500m_m2 -0.5604478  0.3106076  0.04769643 0.76625469
#ForEdge_buffer1500m_index      0.5241537 -0.1388801 -0.68788229 0.48248648
#Nearest_edge_m     -0.3840926 -0.9175866 -0.04174924 0.09362004
#Years_since_frag    0.5134531 -0.2055968  0.72304911 0.41387901

biplot(frag_pca1500)

plot_carbon_hcv$frag_pc1_1500 <- frag_pca1500$x[,1]







###### 2000m #######


frag_pca2000 <- prcomp(plot_carbon_hcv[,c("ForArea_buffer2000m_m2", 
                                          "ForEdge_buffer2000m_index", 
                                          "Nearest_edge_m", 
                                          "Years_since_frag"),],
                       center = TRUE,
                       scale = TRUE)

summary(frag_pca2000)
#                           PC1    PC2    PC3     PC4
#Standard deviation     1.5934 0.8828 0.7020 0.43481
#Proportion of Variance 0.6347 0.1948 0.1232 0.04727
#Cumulative Proportion  0.6347 0.8295 0.9527 1.00000

frag_pca2000
#                          PC1         PC2         PC3       PC4
#ForArea_buffer2000m_m2 -0.5651770  0.31817916 -0.04472507 0.7598267
#ForEdge_buffer2000m_index      0.5191210 -0.20131495 -0.71156840 0.4285511
#Nearest_edge_m     -0.3620672 -0.92169682  0.06933053 0.1207295
#Years_since_frag    0.5291461 -0.09332352  0.69775594 0.4737423

biplot(frag_pca2000)

plot_carbon_hcv$frag_pc1_2000 <- frag_pca2000$x[,1]





############### Soil ordination #####################


### Soil_moisture_perc: gravimetric soil moisture content
# mass of water divided by total mass of soil



# check these for intercorrelation - should be intercorrelated for PCA
cor(as.matrix(plot_carbon_hcv[c("Soil_pH",
                         "Soil_TP_ppm",
                         "Soil_AvP_ppm",
                         "Soil_TN_perc",
                         "Soil_OC_perc",
                         "Soil_CtoN_orgC",
                         "Soil_moisture_perc")]), method = "pearson")


#                      Soil_pH      Soil_TP_ppm    Soil_AvP_ppm    Soil_TN_perc    Soil_OC_perc  Soil_CtoN_orgC Soil_moisture_perc
#Soil_pH             1.0000000  0.64042864  0.5991568  0.4827725  0.4322725 -0.4700029   -0.07943210
#Soil_TP_ppm         0.6404286  1.00000000  0.4703195  0.4568948  0.5131721 -0.3401683   -0.07925029
#Soil_AvP_ppm        0.5991568  0.47031949  1.0000000  0.5637233  0.6497963 -0.2860249    0.22538004
#Soil_TN_perc        0.4827725  0.45689479  0.5637233  1.0000000  0.9038145 -0.7173931    0.63223669
#Soil_OC_perc        0.4322725  0.51317214  0.6497963  0.9038145  1.0000000 -0.3909588    0.60813925
#Soil_CtoN_orgC     -0.4700029 -0.34016832 -0.2860249 -0.7173931 -0.3909588  1.0000000   -0.31225487
#Soil_moisture_perc -0.0794321 -0.07925029  0.2253800  0.6322367  0.6081392 -0.3122549    1.00000000




soil_pca <- prcomp(plot_carbon_hcv[,c("Soil_pH",
                               "Soil_TP_ppm",
                               "Soil_AvP_ppm",
                               "Soil_TN_perc",
                               "Soil_OC_perc",
                               "Soil_CtoN_orgC",
                               "Soil_moisture_perc")],
                   center = TRUE,
                   scale = TRUE)


par(mfrow = c(1,1))

plot(soil_pca)

summary(soil_pca)
#Importance of components:
#                          PC1    PC2    PC3     PC4     PC5     PC6     PC7
#Standard deviation     1.9623 1.2124 0.8849 0.68812 0.48886 0.41701 0.10105
#Proportion of Variance 0.5501 0.2100 0.1119 0.06764 0.03414 0.02484 0.00146
#Cumulative Proportion  0.5501 0.7601 0.8719 0.93956 0.97370 0.99854 1.00000

soil_pca

#                     PC1         PC2         PC3         PC4         PC5         PC6          PC7
#Soil_pH             0.3551584 -0.47491549 -0.10631917  0.30631681  0.73437285  0.05972630  0.017701508
#Soil_TP_ppm         0.3351608 -0.45318733  0.05941805 -0.69163774 -0.18880996  0.39939083 -0.072339392
#Soil_AvP_ppm        0.3821243 -0.16402283  0.47986602  0.57690691 -0.47614675  0.18731109 -0.046726231
#Soil_TN_perc        0.4761569  0.22874053 -0.12608390 -0.08458219 -0.01465765 -0.40680855 -0.729515621
#Soil_OC_perc        0.4534264  0.19308950  0.31987831 -0.24205570  0.07776586 -0.48324370  0.597189958
#Soil_CtoN_orgC     -0.3464623 -0.05260981  0.79221082 -0.16929221  0.33315843 -0.08072979 -0.321599796
#Soil_moisture_perc  0.2513041  0.67067090  0.09527368 -0.02409766  0.28473615  0.62952309  0.003874667


biplot(soil_pca)


autoplot(soil_pca, 
         colour = "#8F8F8F",
         loadings = TRUE,
         loadings.label = FALSE,
         loadings.colour = "cadetblue")+ # same colour as tree height points earlier
  theme_classic()+
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        axis.line.x = element_line(colour = "lightgrey"),
        axis.line.y = element_line(colour = "lightgrey"))+
  coord_fixed() + # x and y scales are the same
  geom_vline(aes(xintercept = 0))+
  geom_hline(aes(yintercept = 0))+
  annotate("text",
           label = "Total N", 
           x = 0.29,
           y = 0.12, colour = "cadetblue")+
  annotate("text",
           label = "Organic C", 
           x = 0.3,
           y = 0.09, colour = "cadetblue")+
  annotate("text",
           label = "Available P", 
           x = 0.28,
           y = -0.07, colour = "cadetblue")+
  annotate("text",
           label = "Moisture", 
           x = 0.11,
           y = 0.34, colour = "cadetblue")+
  annotate("text",
           label = "Total P", 
           x = 0.22,
           y = -0.2, colour = "cadetblue")+
  annotate("text",
           label = "Soil_pH", 
           x = 0.2,
           y = -0.23, colour = "cadetblue")+
  annotate("text",
           label = "C:N", 
           x = -0.2,
           y = -0.02, colour = "cadetblue")
  


# PC1: higher N and org C content with lower org C to N ratio
# PC2: wetter soils, more acidic, lower P content 



ggpairs(plot_carbon_hcv[c("Soil_pH",
                   "Soil_TP_ppm",
                   "Soil_AvP_ppm",
                   "Soil_TN_perc",
                   "Soil_OC_perc",
                   "Soil_CtoN_orgC",
                   "Soil_moisture_perc")],
        columnLabels = c("pH",
                         "Total P/ppm",
                         "Available P/ppm",
                         "Total N (%)",
                         "Organic C (%)",
                         "C:N",
                         "Moisture (%)"),
        diag = list(continuous =
                      wrap("barDiag", bins = 8, colour = "black", fill = "lightgrey"),
                    discrete = "barDiag", na = "naDiag"),
        upper = list(continuous = wrap(ggally_cor, color = "black")))+
  theme_bw()




# bind soil PC1 to plot_carbon_hcv
plot_carbon_hcv$soil_pc1 <- soil_pca$x[,1]

# and for PC2
plot_carbon_hcv$soil_pc2 <- soil_pca$x[,2]





#### also plot boxplots and scatterplots of these metrics and AGC ######


box_sa <- ggplot()+
  geom_boxplot(data = plot_carbon_hcv,
               aes(y = Soil_pH))+
  ylab("pH")+
  scale_colour_manual(values = forest_type_col_OP)+
  theme_classic()+
  theme(legend.position = "none",
        axis.title.x = element_blank(),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank()) 


box_sb <- ggplot()+
  geom_boxplot(data = plot_carbon_hcv,
               aes(y = Soil_TP_ppm))+
  ylab("Total P/ppm")+
  scale_colour_manual(values = forest_type_col_OP)+
  theme_classic()+
  theme(legend.position = "none",
        axis.title.x = element_blank(),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank()) 


box_sc <- ggplot()+
  geom_boxplot(data = plot_carbon_hcv,
               aes(y = Soil_AvP_ppm))+
  ylab("Available P/ppm")+
  scale_colour_manual(values = forest_type_col_OP)+
  theme_classic()+
  theme(legend.position = "none",
        axis.title.x = element_blank(),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank()) 


box_sd <- ggplot()+
  geom_boxplot(data = plot_carbon_hcv,
               aes(y = Soil_TN_perc))+
  ylab("Total N (%)")+
  scale_colour_manual(values = forest_type_col_OP)+
  theme_classic()+
  theme(legend.position = "none",
        axis.title.x = element_blank(),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank()) 


box_se <-  ggplot()+
  geom_boxplot(data = plot_carbon_hcv,
               aes(y = Soil_OC_perc))+
  ylab("Organic C (%)")+
  scale_colour_manual(values = forest_type_col_OP)+
  theme_classic()+
  theme(legend.position = "none",
        axis.title.x = element_blank(),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank()) 



box_sf <-   ggplot()+
  geom_boxplot(data = plot_carbon_hcv,
               aes(y = Soil_CtoN_orgC))+
  ylab("C:N")+
  scale_colour_manual(values = forest_type_col_OP)+
  theme_classic()+
  theme(legend.position = "none",
        axis.title.x = element_blank(),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank()) 

box_sg <-   ggplot()+
  geom_boxplot(data = plot_carbon_hcv,
               aes(y = Soil_moisture_perc))+
  ylab("Moisture (%)")+
  scale_colour_manual(values = forest_type_col_OP)+
  theme_classic()+
  theme(legend.position = "none",
        axis.title.x = element_blank(),
        axis.text.x = element_blank(),
        axis.ticks.x = element_blank()) 


point_a <- ggplot()+
  geom_point(data = plot_carbon_hcv,
             aes(y = Tree_palm_carbon_Mgha,
                 x = Soil_pH,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col_OP)+
  xlab("pH")+
  ylab(bquote("AGC / Mgha"^-1*""))+   
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_line(colour = "lightgrey"),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"))


point_b <- ggplot()+
  geom_point(data = plot_carbon_hcv,
             aes(y = Tree_palm_carbon_Mgha,
                 x = Soil_TP_ppm,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col_OP)+
  xlab("Total P/ppm")+
  ylab(bquote("AGC / Mgha"^-1*""))+   
  scale_x_continuous(breaks = c(100,300))+
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_line(colour = "lightgrey"),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"))

point_c <- ggplot()+
  geom_point(data = plot_carbon_hcv,
             aes(y = Tree_palm_carbon_Mgha,
                 x = Soil_AvP_ppm,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col_OP)+
  xlab("Available P/ppm")+
  ylab(bquote("AGC / Mgha"^-1*""))+   
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_line(colour = "lightgrey"),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"))


point_d <- ggplot()+
  geom_point(data = plot_carbon_hcv,
             aes(y = Tree_palm_carbon_Mgha,
                 x = Soil_TN_perc,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col_OP)+
  xlab("Total N (%)")+
  ylab(bquote("AGC / Mgha"^-1*""))+   
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_line(colour = "lightgrey"),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"))


point_e <- ggplot()+
  geom_point(data = plot_carbon_hcv,
             aes(y = Tree_palm_carbon_Mgha,
                 x = Soil_OC_perc,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col_OP)+
  xlab("Organic C (%)")+
  ylab(bquote("AGC / Mgha"^-1*""))+   
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_line(colour = "lightgrey"),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"))


point_f <- ggplot()+
  geom_point(data = plot_carbon_hcv,
             aes(y = Tree_palm_carbon_Mgha,
                 x = Soil_CtoN_orgC,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col_OP)+
  xlab("C:N")+
  ylab(bquote("AGC / Mgha"^-1*""))+   
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_line(colour = "lightgrey"),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"))

point_g <- ggplot()+
  geom_point(data = plot_carbon_hcv,
             aes(y = Tree_palm_carbon_Mgha,
                 x = Soil_moisture_perc,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col_OP)+
  xlab("Moisture (%)")+
  ylab(bquote("AGC / Mgha"^-1*""))+   
  scale_x_continuous(breaks = c(0.2, 0.3))+
  theme_classic()+
  theme(legend.position = "none",
        panel.grid.major.x = element_line(colour = "lightgrey"),
        panel.grid.major.y = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"))





plot_grid(box_sa,
          box_sb, 
          box_sc, 
          box_sd, 
          box_se,
          box_sf,
          box_sg,
          NULL,
          point_a,
          point_b, 
          point_c, 
          point_d, 
          point_e,
          point_f,
          point_g,
          nrow = 4, 
          labels = c("(a)", "(b)", "(c)", "(d)","(e)","(f)","(g)", "",
                     "(h)", "(i)", "(j)", "(k)", "(l)", "(m)", "(n)"),
          label_size = 10,
          rel_heights = c(1.2,1.2,2,2),
          scale = 0.85)










############### FITTING GAMM  ##############


#### scale the predictors #####

# create list of scaled variables which also holds scaling/centering factors
pred_scale <- scale(plot_carbon_hcv[,c("Elevation_masl",
                                       "Slope_deg",
                                       "soil_pc1",
                                       "soil_pc2",
                                       "frag_pc1", 
                                       "frag_pc1_200",
                                       "frag_pc1_500",
                                       "frag_pc1_1500",
                                       "frag_pc1_2000")])
# rename columns of scaled variables

colnames(pred_scale) <- paste0(colnames(pred_scale), ".s")


plot_carbon_hcv <- cbind(plot_carbon_hcv,
                         pred_scale[1:37,1:9]) # bind scaled values only (not attrs)


# check these variables for intercorrelation

cor(as.matrix(plot_carbon_hcv[c("Elevation_masl.s",
                         "Slope_deg.s",
                         "frag_pc1.s",
                         "soil_pc1.s",
                         "soil_pc2.s")]), method = "pearson")

#                 Elevation_masl.s Slope_deg.s   frag_pc1.s                soil_pc1.s                soil_pc2.s
#Elevation_masl.s      1.00000000   0.088843523 -0.252638418  0.2148932725668871723812  0.2540435830606341816029
#Slope_deg.s        0.08884352   1.000000000 -0.007857189  0.3611069925377082823204 -0.3643967663587158178906
#frag_pc1.s          -0.25263842  -0.007857189  1.000000000  0.3870763997707961645567 -0.1119685500276830086852
#soil_pc1.s           0.21489327   0.361106993  0.387076400  1.0000000000000000000000 -0.0000000000000001524328
#soil_pc2.s           0.25404358  -0.364396766 -0.111968550 -0.0000000000000001524328  1.0000000000000000000000



###### main model for 1km radius frag index ######

##### running GAMM fitting slope and elevation as smoothers because 
# the shapes of their influences on AGC can be complicated
# and I'm not primarily interested in their effects


# model chooses knots; Gamma and inverse link
gamm1 <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1.s + soil_pc1.s + soil_pc2.s +
                     s(Elevation_masl.s, k=-1, bs = "cs") +
                     s(Slope_deg.s, k = -1, bs = "cs"),
                   random = ~(1|Site_code),
                   data = plot_carbon_hcv,
                   family = gaussian(link = "identity"),
               REML = FALSE)

summary(gamm1$gam)
summary(gamm1$mer)

#### 0 ESTIMATES OF VARIANCE FOR RANDOM EFFECTS OF SLOPE 
# fit slope as fixed effect instead


gamm1 <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1.s + soil_pc1.s + soil_pc2.s +Slope_deg.s+
                 s(Elevation_masl.s, k=-1, bs = "cs"),
               random = ~(1|Site_code),
               data = plot_carbon_hcv,
               family = gaussian(link = "identity"),
               REML = FALSE)


summary(gamm1$mer)  
summary(gamm1$gam)

logLik(gamm1$mer)# -167.4794 (df=8)

hist(unlist(ranef(gamm1$mer)$Site_code), col="grey")
plot(gamm1$mer)
qqnorm(resid(gamm1$mer))

# drop significant terms one by one
summary(gamm1$gam)


# first remove slope
gamm1_b <-  gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1.s + soil_pc1.s + soil_pc2.s +
                        s(Elevation_masl.s, k=-1, bs = "cs"),
                      random = ~(1|Site_code),
                      data = plot_carbon_hcv,
                      family = gaussian(link = "identity"),
                  REML = FALSE)

summary(gamm1_b$gam)


# remove soil pc2
gamm1_c <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1.s + soil_pc1.s +
                   s(Elevation_masl.s, k=-1, bs = "cs"),
                 random = ~(1|Site_code),
                 data = plot_carbon_hcv,
                 family = gaussian(link = "identity"),
                 REML = FALSE)


summary(gamm1_c$gam)


# remove soil pc1

gamm1_d <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1.s +
                   s(Elevation_masl.s, k=-1, bs = "cs"),
                 random = ~(1|Site_code),
                 data = plot_carbon_hcv,
                 family = gaussian(link = "identity"),
                 REML = FALSE)


summary(gamm1_d$gam)

# remove fragmentation 
gamm1_e <- gamm4(Tree_palm_carbon_Mgha  ~ 1 +
                   s(Elevation_masl.s, k=-1, bs = "cs"),
                 random = ~(1|Site_code),
                 data = plot_carbon_hcv,
                 family = gaussian(link = "identity"),
                 REML = FALSE)

summary(gamm1_e$gam)
summary(gamm1_e$mer)

logLik(gamm1_e$mer) # -169.2342 (df=4)





###### NOW RUN THE SAME MODEL FOR DIFFERENT BUFFER SIZES ####

gamm200 <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_200.s + soil_pc1.s + soil_pc2.s +Slope_deg.s+
                   s(Elevation_masl.s, k=-1, bs = "cs"),
                 random = ~(1|Site_code),
                 data = plot_carbon_hcv,
                 family = gaussian(link = "identity"),
                 REML = FALSE)


summary(gamm200$gam)

logLik(gamm200$mer)
#'log Lik.' -153.5379 (df=8)

gamm200_b <-gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_200.s + soil_pc1.s + soil_pc2.s+
        s(Elevation_masl.s, k=-1, bs = "cs"),
      random = ~(1|Site_code),
      data = plot_carbon_hcv,
      family = gaussian(link = "identity"),
      REML = FALSE)

summary(gamm200_b$gam)

gamm200_c <-gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_200.s + soil_pc1.s +
                    s(Elevation_masl.s, k=-1, bs = "cs"),
                  random = ~(1|Site_code),
                  data = plot_carbon_hcv,
                  family = gaussian(link = "identity"),
                  REML = FALSE)

summary(gamm200_c$gam)

gamm200_d <-gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_200.s + +
                    s(Elevation_masl.s, k=-1, bs = "cs"),
                  random = ~(1|Site_code),
                  data = plot_carbon_hcv,
                  family = gaussian(link = "identity"),
                  REML = FALSE)

summary(gamm200_d$gam)






gamm500 <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_500.s + soil_pc1.s + soil_pc2.s +Slope_deg.s+
                   s(Elevation_masl.s, k=-1, bs = "cs"),
                 random = ~(1|Site_code),
                 data = plot_carbon_hcv,
                 family = gaussian(link = "identity"),
                 REML = FALSE)


summary(gamm500$gam)

logLik(gamm500$mer)
## 'log Lik.'  -167.214 (df=8)


gamm500_b <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_500.s + soil_pc1.s + soil_pc2.s+
                   s(Elevation_masl.s, k=-1, bs = "cs"),
                 random = ~(1|Site_code),
                 data = plot_carbon_hcv,
                 family = gaussian(link = "identity"),
                 REML = FALSE)


summary(gamm500_b$gam)

gamm500_c <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_500.s + soil_pc1.s +
                     s(Elevation_masl.s, k=-1, bs = "cs"),
                   random = ~(1|Site_code),
                   data = plot_carbon_hcv,
                   family = gaussian(link = "identity"),
                   REML = FALSE)


summary(gamm500_c$gam)

# remove slope because this has higher p val than soil pc1
gamm500_d <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_500.s + soil_pc1.s,
                   random = ~(1|Site_code),
                   data = plot_carbon_hcv,
                   family = gaussian(link = "identity"),
                   REML = FALSE)


summary(gamm500_d$gam)

# then remove soil pc1
gamm500_e <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_500.s,
                   random = ~(1|Site_code),
                   data = plot_carbon_hcv,
                   family = gaussian(link = "identity"),
                   REML = FALSE)

summary(gamm500_e$gam)
# no sig terms if following backwards selection for this model








gamm1500 <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_1500.s + soil_pc1.s + soil_pc2.s +Slope_deg.s+
                    s(Elevation_masl.s, k=-1, bs = "cs"),
                  random = ~(1|Site_code),
                  data = plot_carbon_hcv,
                  family = gaussian(link = "identity"),
                  REML = FALSE)


summary(gamm1500$gam)

logLik(gamm1500$mer) #  -167.9389 (df=8)


gamm1500_b <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_1500.s + soil_pc1.s + soil_pc2.s +
                    s(Elevation_masl.s, k=-1, bs = "cs"),
                  random = ~(1|Site_code),
                  data = plot_carbon_hcv,
                  family = gaussian(link = "identity"),
                  REML = FALSE)

summary(gamm1500_b$gam)

gamm1500_c <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_1500.s + soil_pc1.s +
                      s(Elevation_masl.s, k=-1, bs = "cs"),
                    random = ~(1|Site_code),
                    data = plot_carbon_hcv,
                    family = gaussian(link = "identity"),
                    REML = FALSE)

summary(gamm1500_c$gam)


gamm1500_d <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_1500.s + 
                      s(Elevation_masl.s, k=-1, bs = "cs"),
                    random = ~(1|Site_code),
                    data = plot_carbon_hcv,
                    family = gaussian(link = "identity"),
                    REML = FALSE)

summary(gamm1500_d$gam)







gamm2000 <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_2000.s + soil_pc1.s + soil_pc2.s +Slope_deg.s+
                    s(Elevation_masl.s, k=-1, bs = "cs"),
                  random = ~(1|Site_code),
                  data = plot_carbon_hcv,
                  family = gaussian(link = "identity"),
                  REML = FALSE)


summary(gamm2000$gam)

logLik(gamm2000$mer) #-168.0965 (df=8)



gamm2000_b <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_2000.s + soil_pc1.s + soil_pc2.s+
                    s(Elevation_masl.s, k=-1, bs = "cs"),
                  random = ~(1|Site_code),
                  data = plot_carbon_hcv,
                  family = gaussian(link = "identity"),
                  REML = FALSE)


summary(gamm2000_b$gam)


gamm2000_c <- gamm4(Tree_palm_carbon_Mgha  ~ frag_pc1_2000.s + soil_pc2.s+
                      s(Elevation_masl.s, k=-1, bs = "cs"),
                    random = ~(1|Site_code),
                    data = plot_carbon_hcv,
                    family = gaussian(link = "identity"),
                    REML = FALSE)


summary(gamm2000_c$gam)


gamm2000_d <- gamm4(Tree_palm_carbon_Mgha  ~ soil_pc2.s+
                      s(Elevation_masl.s, k=-1, bs = "cs"),
                    random = ~(1|Site_code),
                    data = plot_carbon_hcv,
                    family = gaussian(link = "identity"),
                    REML = FALSE)


summary(gamm2000_d$gam)








#### because final model doesn't include frag, it's the same for all
gamm1_final <- gamm1_e



###### get predictions, CIs and plot #####

## generate new data for the predictions###

# predict AGC for elevation
newdata <- data.frame(Elevation_masl.s = seq(min(plot_carbon_hcv$Elevation_masl.s),
                                      max(plot_carbon_hcv$Elevation_masl.s),
                                      length.out = 100))

newdata$Site_code <- NA

pred <- predict(gamm1_final$gam, newdata, se.fit = TRUE)


newdata <- cbind(newdata, pred)

# add in CIs
newdata <- within(newdata, {
  lower = fit-1.96*se.fit
  upper = fit+1.96*se.fit
})

head(newdata)


# convert the scaled variable to original scale

newdata$Elevation_masl <- newdata$Elevation_masl.s * attr(pred_scale,"scaled:scale")["Elevation_masl"] + attr(pred_scale,"scaled:center")["Elevation_masl"]

# check this is the same as original values
min(newdata$Elevation_masl) == min(plot_carbon_hcv$Elevation_masl)
max(newdata$Elevation_masl) == max(plot_carbon_hcv$Elevation_masl)




# plot elevation spline
elev <- ggplot()+
  geom_line(data = newdata,
             aes(x = Elevation_masl,
                 y = fit)) +
  geom_line(data = newdata,
            aes(x = Elevation_masl,
                y = lower),
            linetype = "dashed") +
  geom_line(data = newdata,
            aes(x = Elevation_masl,
                y = upper),
            linetype = "dashed") +
  geom_point(data = plot_carbon_hcv,
             aes(x = Elevation_masl,
                 y = Tree_palm_carbon_Mgha,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col,
                      guide = F) +
  theme_classic()+
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "bottom",
        legend.background = element_rect(colour = "black"))+
  ylab(bquote("AGC / Mg ha"^-1*"")) +
  xlab("Elevation/m.a.s.l.")



#### scatterplots of other variables in model ####



# soil pc1 
soil_1 <- ggplot()+
  geom_point(data = plot_carbon_hcv,
             aes(x = soil_pc1,
                 y = Tree_palm_carbon_Mgha,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col,
                      guide = F) +
  theme_classic()+
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "bottom",
        legend.background = element_rect(colour = "black"))+
  ylab(bquote("AGC / Mg ha"^-1*"")) +
  xlab("Soil PC1")


# soil pc2
soil_2 <- ggplot()+
  geom_point(data = plot_carbon_hcv,
             aes(x = soil_pc2,
                 y = Tree_palm_carbon_Mgha,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col,
                      guide = F) +
  theme_classic()+
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "bottom",
        legend.background = element_rect(colour = "black"))+
  ylab(bquote("AGC / Mg ha"^-1*"")) +
  xlab("Soil PC2")


# Fragmentation 1km - though no effect
frag <- ggplot()+
  geom_point(data = plot_carbon_hcv,
             aes(x = frag_pc1,
                 y = Tree_palm_carbon_Mgha,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col,
                      guide = F) +
  theme_classic()+
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "bottom",
        legend.background = element_rect(colour = "black"))+
  ylab(bquote("AGC / Mg ha"^-1*"")) +
  xlab("Fragmentation index (PC1)")

# slope - though no effect
slope <- ggplot()+
  geom_point(data = plot_carbon_hcv,
             aes(x = Slope_deg,
                 y = Tree_palm_carbon_Mgha,
                 colour = Forest_type))+
  scale_colour_manual(values = forest_type_col,
                      guide = F) +
  theme_classic()+
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(10, 10, 0, 0), "points"),
        legend.position = "bottom",
        legend.background = element_rect(colour = "black"))+
  ylab(bquote("AGC / Mg ha"^-1*"")) +
  xlab("Slope/")



plot_grid(frag, soil_1, soil_2, slope, elev, scale = 0.9,
          labels = c("(a)", "(b)", "(c)", "(d)", "(e)"),
          label_size = 10,
          nrow = 2)








########################### RESULTS 4 CARBON AND DIVERSITY #################################


# How does carbon stock relate to floral diversity?

# fisher's alpha and richness for each of 3 tree groups 
# adult trees >=10cm dbh
# saplings 2-10cm dbh
# seedlings <2cm dbh




# get diversity metrics for set-asides only
div_hcv <- dplyr::select(plot_carbon,
                         Tree_palm_carbon_Mgha,
                         Site_plot_code,
                         Forest_type,
                         Site_code,
                         Fisher_alpha_seedling,
                         Fisher_alpha_sapling,
                         Fisher_alpha_tree,
                         Richness_seedling,
                         Richness_sapling,
                         Richness_tree) %>%
  filter(Forest_type == "HCV")





############## LMEs of carbon on Fisher's alpha #########

####### LME with size class and site as random effects ##########


div_long <- div_hcv %>% dplyr::select(Site_plot_code,
                                  Site_code,
                                  Fisher_alpha_seedling,
                                  Fisher_alpha_sapling,
                                  Fisher_alpha_tree) %>%
  gather(c(3:5),
         key = "Size_class",
         value = "Fisher") %>% 
  left_join(dplyr::select(div_hcv, Site_plot_code, Tree_palm_carbon_Mgha), by = "Site_plot_code")

div_long

div_long$Size_class <- gsub(div_long$Size_class, pattern = "Fisher_alpha_", replacement = "")
div_long$Size_class <- as.factor(div_long$Size_class)


# filter dataset to remove the extreme outliers

filter(div_long, Fisher > 100)
#    Code  Site_code Size_class      Fisher Tree_palm_carbon_Mgha
#1 F14P2 F14           seed       2147483650                   35.6
#2 F16P3 F16           seed       2147483650                   63.4
#3 F2P3  F2            seed        536870961.                  74.3
#4 F11P1 F11           sap        4294967302.                  48.9


div_long_hcv <- filter(div_long,
                       Fisher <=100)




# scale and centre total carbon for modelling
AGC_scale <- scale(div_long_hcv$Tree_palm_carbon_Mgha)

div_long_hcv$AGC_scale <- AGC_scale[,1]

# to access the scale and center
attr(AGC_scale, "scaled:scale") # 25.00392
attr(AGC_scale, "scaled:center") # 52.44526



####### BLME with size class as fixed effect ##########
## fit size class as fixed effect to overcome issues of fitting 

# use Gamma family and identity link - gives lowest AIC and removes patterns from residuals

div_glmm <- bglmer(Fisher ~ AGC_scale * Size_class + 
                   (1|Site_code), # random intercept
                 data = div_long_hcv,
                 family = Gamma(link= "identity"), 
                 cov.prior = gamma(shape = 2.5, rate = 0), 
                 control = glmerControl(optimizer ="Nelder_Mead")) 



# check for homoscedasticity of residuals 
plot(div_glmm)

# QQ plot to check normality of residuals - fixed effect
qqnorm(resid(div_glmm))

# QQ plot to check random effects
qqnorm(ranef(div_glmm)$Site_code[,1])


AIC(div_glmm) #  706.1368

summary(div_glmm)

anova(div_glmm)
drop1(div_glmm)

div_glmm@theta # 7.303863




## compare to model without interaction term

div_glmm2 <-  bglmer(Fisher ~ AGC_scale + Size_class + 
                       (1|Site_code), # random intercept
                     data = div_long_hcv,
                     family = Gamma(link= "identity"), 
                     cov.prior = gamma(shape = 2.5, rate = 0), 
                     control = glmerControl(optimizer ="Nelder_Mead")) 


summary(div_glmm2)


# anova comparing these
anova(div_glmm2, div_glmm)

#Data: div_long_hcv
#Models:
#  div_glmm2: Fisher ~ AGC_scale + Size_class + (1 | Site_code)
# div_glmm: Fisher ~ AGC_scale * Size_class + (1 | Site_code)
#           Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)  
#div_glmm2  6 708.31 724.35 -348.16   696.31                           
#div_glmm   8 706.14 727.52 -345.07   690.14 6.1776      2    0.04556 *

### keep interaction term




####### RICHNESS AND AGC #######


rich_long_hcv <- div_hcv %>% dplyr::select(Site_plot_code,
                                   Site_code,
                                   Richness_seedling,
                                   Richness_sapling,
                                   Richness_tree) %>%
  gather(c(3:5),
         key = "Size_class",
         value = "Richness")%>% 
  left_join(dplyr::select(div_hcv, Site_plot_code, Tree_palm_carbon_Mgha), by = "Site_plot_code")


rich_long_hcv$Size_class <- gsub(rich_long_hcv$Size_class, pattern = "Richness_", replacement = "")
rich_long_hcv$Size_class <- as.factor(rich_long_hcv$Size_class)





# scale and centre total carbon for modelling
# this allows the model with size class as fixed effect to
# converge - didn't before
AGC_scale2 <- scale(rich_long_hcv$Tree_palm_carbon_Mgha)

rich_long_hcv$AGC_scale <- AGC_scale2[,1]

# to access the scale and center
attr(AGC_scale2, "scaled:scale") # 24.70957
attr(AGC_scale2, "scaled:center") # 52.55781



####### Bayesian GLMM with size class as fixed effect ##########
## fit size class as fixed effect to overcome issues of fitting 



### poisson, log link for count data ##

rich_bglmm <-  bglmer(Richness ~ AGC_scale * Size_class + 
                        (1|Site_code), # random intercept
                      data = rich_long_hcv,
                      family = poisson(link= "log"), 
                     cov.prior = gamma(shape = 2.5, rate = 0), 
                     control = glmerControl(optimizer ="Nelder_Mead")) 

summary(rich_bglmm)
plot(rich_bglmm)
qqnorm(resid(rich_bglmm))
drop1(rich_bglmm) # can drop interaction term - AIC is lower without this


## compare to model without interaction term

rich_bglmm2 <-  bglmer(Richness ~ AGC_scale + Size_class + 
                         (1|Site_code), # random intercept
                       data = rich_long_hcv,
                       family = poisson(link= "log"), 
                       cov.prior = gamma(shape = 2.5, rate = 0), 
                       control = glmerControl(optimizer ="Nelder_Mead")) 

summary(rich_bglmm2)


# anova comparing these
anova(rich_bglmm2, rich_bglmm)

#rich_bglmm2: Richness ~ AGC_scale + Size_class + (1 | Site_code)
#rich_bglmm: Richness ~ AGC_scale * Size_class + (1 | Site_code)
             #Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)
#rich_bglmm2  5 622.59 636.14 -306.30   612.59                         
#rich_bglmm   7 625.65 644.62 -305.82   611.65 0.9435      2     0.6239

# no support for including interaction term - which had very small effect

# USE rich_bglmm2

drop1(rich_bglmm2) # AGC goes up if you remove either of these - keep both


# get the chisq for each of the individual terms 

rich_bglmm3 <-  bglmer(Richness ~ Size_class + 
                         (1|Site_code), # random intercept
                       data = rich_long_hcv,
                       family = poisson(link= "log"), 
                       cov.prior = gamma(shape = 2.5, rate = 0), 
                       control = glmerControl(optimizer ="Nelder_Mead")) 

anova(rich_bglmm2, rich_bglmm3)

# rich_bglmm3: Richness ~ Size_class + (1 | Site_code)
#rich_bglmm2: Richness ~ AGC_scale + Size_class + (1 | Site_code)
#            Df    AIC    BIC  logLik deviance  Chisq Chi Df Pr(>Chisq)    
#rich_bglmm3  4 643.48 654.32 -317.74   635.48                             
#rich_bglmm2  5 622.59 636.14 -306.30   612.59 22.888      1  1.717e-06 ***


rich_bglmm4 <-  bglmer(Richness ~ AGC_scale + 
                         (1|Site_code), # random intercept
                       data = rich_long_hcv,
                       family = poisson(link= "log"), 
                       cov.prior = gamma(shape = 2.5, rate = 0), 
                       control = glmerControl(optimizer ="Nelder_Mead")) 

anova(rich_bglmm2, rich_bglmm4)

#rich_bglmm4: Richness ~ AGC_scale + (1 | Site_code)
#rich_bglmm2: Richness ~ AGC_scale + Size_class + (1 | Site_code)
             #Df    AIC    BIC  logLik deviance Chisq Chi Df Pr(>Chisq)    
#rich_bglmm4  3 937.49 945.62 -465.75   931.49                            
#rich_bglmm2  5 622.59 636.14 -306.30   612.59 318.9      2  < 2.2e-16 ***




#### predict for plotting #####

############ fisher's alpha ############

div_effect <- Effect(c("AGC_scale", "Size_class"), div_glmm, se=T, xlevels = 100)


div_pred <- cbind(div_effect$x,
                  div_effect$fit,
                  div_effect$lower,
                  div_effect$upper)

colnames(div_pred)[3:5] <- c("fisher", "lower", "upper")

div_pred$Tree_palm_carbon_Mgha <- div_pred$AGC_scale * attr(AGC_scale, "scaled:scale") + attr(AGC_scale, "scaled:center") 



############ richness ############

rich_effect <- Effect(c("AGC_scale", "Size_class"), mod = rich_bglmm2, se=T, xlevels = 100)


rich_pred <- cbind(rich_effect$x,
                   rich_effect$fit,
                   rich_effect$lower,
                   rich_effect$upper)

colnames(rich_pred)[3:5] <- c("richness", "lower", "upper")

rich_pred$Tree_palm_carbon_Mgha <- rich_pred$AGC_scale * attr(AGC_scale2, "scaled:scale") + attr(AGC_scale2, "scaled:center") 




######### plotting ###########


# bind on forest type
div_long_hcv <- left_join(div_long_hcv,
                          dplyr::select(plot_carbon,
                                        Site_plot_code,
                                        Forest_type),
                          by = "Site_plot_code")

rich_long_hcv <- left_join(rich_long_hcv,
                          dplyr::select(plot_carbon,
                                        Site_plot_code,
                                        Forest_type),
                          by = "Site_plot_code")




# can use legend from this plot if I want it at the bottom
a <- ggplot()+
  geom_point(data = filter(div_long_hcv, Size_class == "seedling"),
             aes(x = Tree_palm_carbon_Mgha,
                 y = Fisher,
                 colour = Forest_type)) +
  scale_colour_manual(values = forest_type_col,
                      guide = FALSE) +
  geom_line(data = filter(div_pred, Size_class == "seedling"),
            aes(x = Tree_palm_carbon_Mgha,
                y = lower),
            linetype = "dashed")+
  geom_line(data = filter(div_pred, Size_class == "seedling"),
            aes(x = Tree_palm_carbon_Mgha,
                y = upper),
            linetype = "dashed")+
  geom_line(data = filter(div_pred, Size_class == "seedling"),
            aes(x = Tree_palm_carbon_Mgha,
                y = fisher))+
  theme_classic()+
  scale_x_continuous(limits = c(0, 125), expand = c(0,0))+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(10, 10, 10, 10), "points"))+
  ylab("Fisher's alpha") +
  xlab(bquote("AGC in plot/Mg ha"^-1*""))



b <- ggplot()+
  geom_point(data = filter(div_long_hcv, Size_class == "sapling"),
             aes(x = Tree_palm_carbon_Mgha,
                 y = Fisher,
                 colour = Forest_type)) +
  scale_colour_manual(values = forest_type_col,
                      guide = FALSE) +
  geom_line(data = filter(div_pred, Size_class == "sapling"),
            aes(x = Tree_palm_carbon_Mgha,
                y = lower),
            linetype = "dashed")+
  geom_line(data = filter(div_pred, Size_class == "sapling"),
            aes(x = Tree_palm_carbon_Mgha,
                y = upper),
            linetype = "dashed")+
  geom_line(data = filter(div_pred, Size_class == "sapling"),
            aes(x = Tree_palm_carbon_Mgha,
                y = fisher))+
  theme_classic()+
  scale_x_continuous(limits = c(0, 125), expand = c(0,0))+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(10, 10, 10, 10), "points"))+
  ylab("Fisher's alpha") +
  xlab(bquote("AGC in plot/Mg ha"^-1*""))



c <- ggplot()+
  geom_point(data = filter(div_long_hcv, Size_class == "tree"),
             aes(x = Tree_palm_carbon_Mgha,
                 y = Fisher,
                 colour = Forest_type)) +
  scale_colour_manual(values = forest_type_col,
                      guide = FALSE) +
  geom_line(data = filter(div_pred, Size_class == "tree"),
            aes(x = Tree_palm_carbon_Mgha,
                y = lower),
            linetype = "dashed")+
  geom_line(data = filter(div_pred, Size_class == "tree"),
            aes(x = Tree_palm_carbon_Mgha,
                y = upper),
            linetype = "dashed")+
  geom_line(data = filter(div_pred, Size_class == "tree"),
            aes(x = Tree_palm_carbon_Mgha,
                y = fisher))+
  theme_classic()+
  scale_x_continuous(limits = c(0, 125), expand = c(0,0))+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(10, 10, 10, 10), "points"))+
  ylab("Fisher's alpha") +
  xlab(bquote("AGC in plot/Mg ha"^-1*""))



## need to back-transform predictions for genus richness (because of log link)

d <- ggplot()+
  geom_point(data = filter(rich_long_hcv, Size_class == "seedling"),
             aes(x = Tree_palm_carbon_Mgha,
                 y = Richness,
                 colour = Forest_type)) +
  scale_colour_manual(values = forest_type_col,
                      guide = FALSE) +
  geom_line(data = filter(rich_pred, Size_class == "seedling"),
            aes(x = Tree_palm_carbon_Mgha,
                y = exp(lower)),
            linetype = "dashed")+
  geom_line(data = filter(rich_pred, Size_class == "seedling"),
            aes(x = Tree_palm_carbon_Mgha,
                y = exp(upper)),
            linetype = "dashed")+
  geom_line(data = filter(rich_pred, Size_class == "seedling"),
            aes(x = Tree_palm_carbon_Mgha,
                y = exp(richness)))+
  theme_classic()+
  scale_x_continuous(limits = c(0, 125), expand = c(0,0))+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(10, 10, 10, 10), "points"))+
  ylab("Genus richness") +
  xlab(bquote("AGC in plot/Mg ha"^-1*""))



e <- ggplot()+
  geom_point(data = filter(rich_long_hcv, Size_class == "sapling"),
             aes(x = Tree_palm_carbon_Mgha,
                 y = Richness,
                 colour = Forest_type)) +
  scale_colour_manual(values = forest_type_col,
                      guide = FALSE) +
  geom_line(data = filter(rich_pred, Size_class == "sapling"),
            aes(x = Tree_palm_carbon_Mgha,
                y = exp(lower)),
            linetype = "dashed")+
  geom_line(data = filter(rich_pred, Size_class == "sapling"),
            aes(x = Tree_palm_carbon_Mgha,
                y = exp(upper)),
            linetype = "dashed")+
  geom_line(data = filter(rich_pred, Size_class == "sapling"),
            aes(x = Tree_palm_carbon_Mgha,
                y = exp(richness)))+
  theme_classic()+
  scale_x_continuous(limits = c(0, 125), expand = c(0,0))+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(10, 10, 10, 10), "points"))+
  ylab("Genus richness") +
  xlab(bquote("AGC in plot/Mg ha"^-1*""))



f <- ggplot()+
  geom_point(data = filter(rich_long_hcv, Size_class == "tree"),
             aes(x = Tree_palm_carbon_Mgha,
                 y = Richness,
                 colour = Forest_type)) +
  scale_colour_manual(values = forest_type_col,
                      guide = FALSE) +
  geom_line(data = filter(rich_pred, Size_class == "tree"),
            aes(x = Tree_palm_carbon_Mgha,
                y = exp(lower)),
            linetype = "dashed")+
  geom_line(data = filter(rich_pred, Size_class == "tree"),
            aes(x = Tree_palm_carbon_Mgha,
                y = exp(upper)),
            linetype = "dashed")+
  geom_line(data = filter(rich_pred, Size_class == "tree"),
            aes(x = Tree_palm_carbon_Mgha,
                y = exp(richness)))+
  theme_classic()+
  scale_x_continuous(limits = c(0, 125), expand = c(0,0))+
  # sets limits and removes gap between lower limit and the axis
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(10, 10, 10, 10), "points"))+
  ylab("Genus richness") +
  xlab(bquote("AGC in plot/Mg ha"^-1*""))




abc <- plot_grid(a +ggtitle("Seedlings")+
                   theme(plot.title = element_text(hjust = 0.5, size = 13)) , 
                 #gets the titles central
                 b + ggtitle("Saplings")+
                   theme(plot.title = element_text(hjust = 0.5, size = 13)), 
                 c + ggtitle("Adult trees")+
                   theme(plot.title = element_text(hjust = 0.5, size = 13)),
                 labels = c("(a)", "(b)", "(c)"), 
                 nrow = 1,
                 label_size = 10,
                 vjust = 4)# moves labels down to align with top of plots


def <- plot_grid(d,e,f,
                 labels = c("(d)", "(e)", "(f)"), 
                 nrow = 1,
                 label_size = 10)

plot_grid(abc,
          def,
          rel_heights = c(1.1,1),
          nrow = 2)













###################### RESULTS 5 OIL PALM PLANTATION-SCALE CARBON #################


### create site carbon dataset, summarizing the plot-level data
# in order to get the distribution of AGC per HCV site

###### LATER REMOVE SD AND SE CALCULATIONS? DON'T USE? ####

site_carbon <- plot_carbon %>%
  group_by(Site_code) %>%
  summarise(Tree_palm_carbon_Mgha_mean = mean(Tree_palm_carbon_Mgha),#*
            Tree_palm_carbon_Mgha_sd = sd(Tree_palm_carbon_Mgha),
            n_plots = n(),
            Tree_palm_carbon_Mgha_se = ifelse(n_plots != 2,
                                              Tree_palm_carbon_Mgha_sd/sqrt(n_plots),
                                          NA))# calculate standard error for total C for each site


names(site_carbon)[names(site_carbon) == "Tree_palm_carbon_Mgha_mean"] <- "Tree_palm_carbon_Mgha"


site_carbon <- left_join(site_carbon,
                         distinct(dplyr::select(plot_carbon, 
                                       Site_code,
                                       Forest_type)), # remove repeats for each fragment
                         by = "Site_code")


# range of HCV site level carbon
min(filter(site_carbon, Forest_type == "HCV")$Tree_palm_carbon_Mgha)# 28.07306
max(filter(site_carbon, Forest_type == "HCV")$Tree_palm_carbon_Mgha) # 96.59351

# mean, percentiles
mean(filter(site_carbon, Forest_type == "HCV")$Tree_palm_carbon_Mgha) # 53.78172
quantile(filter(site_carbon, Forest_type == "HCV")$Tree_palm_carbon_Mgha, probs = 0.975) # 91.6
quantile(filter(site_carbon, Forest_type == "HCV")$Tree_palm_carbon_Mgha, probs = 0.025) # 29.038



########## Plot how changing % of HCV in an oil palm landscape affects average C 
# stock across landscape, and show cont forest too



############# Use site-level C stock estimation (means) to get PIs ##############

# This accounts for site-level variation rather than plot-level variation
# (taking mean of all plots at site)

# note that with LMEs estimating variation around random effect (ie site) is very difficult
# so for now I think this is the best way 
site_carbon <- mutate(site_carbon,
                                   Forest_type2 = ifelse(Forest_type == "HCV", "HCV",
                                                         ifelse(Forest_type == "Oil palm", "Oil palm",
                                                                "Continuous")))

site_carbon$Forest_type2 <- factor(site_carbon$Forest_type2)


site_carbon_summary <- site_carbon %>% group_by(Forest_type2) %>%
  summarise(carbon_mean = mean(Tree_palm_carbon_Mgha),
            carbon_sd = sd(Tree_palm_carbon_Mgha),
            Q025 = quantile(Tree_palm_carbon_Mgha, probs = 0.025),
            Q975 = quantile(Tree_palm_carbon_Mgha, probs = 0.975))


site_carbon_summary <- mutate(site_carbon_summary,
                              PI_upr = carbon_mean + 1.96 *carbon_sd,
                              PI_lwr = carbon_mean -1.96 * carbon_sd)

site_carbon_summary$Forest_type2 <- factor(site_carbon_summary$Forest_type2,
                                          levels = c("HCV",
                                                     "Continuous",
                                                     "Oil palm"))


site_carbon_summary[3,1] <- "Oil palm"
site_carbon_summary[3,2] <- OP_C_mean
site_carbon_summary[3,6] <- OP_C_mean + 1.96 *OP_C_SD
site_carbon_summary[3,7] <- OP_C_mean - 1.96 *OP_C_SD





site_carbon_summary
#   Forest_type2 carbon_mean carbon_sd  Q025  Q975 PI_upr PI_lwr
#1 Continuous         114.       18.1  99.4 137.   149.   78.0 
#2 HCV                 53.8      19.5  29.0  91.6   92.0  15.5 
#3 Oil palm            30.3      NA    NA    NA     68.2  -7.56
 



# rewrite the hcv_perc
hcv_perc <- data.frame(perc_hcv = seq(0,100,1))
hcv_perc <- mutate(hcv_perc,
                   C_mean = (100 - perc_hcv) * 0.01 *  site_carbon_summary$carbon_mean[3] + 
                     perc_hcv * 0.01 * site_carbon_summary$carbon_mean[2], # OP mean plus HCV mean
                   C_low = (100 - perc_hcv) * 0.01 * site_carbon_summary$PI_lwr[3] +
                     perc_hcv * 0.01 * site_carbon_summary$PI_lwr[2], # OP lower 95PI plus HCV lower 95PI
                   C_high = (100 - perc_hcv) * 0.01 * site_carbon_summary$PI_upr[3] +
                     perc_hcv * 0.01 * site_carbon_summary$PI_upr[2], # OP upper 95PI plus HCV upper 95PI
                   C_025 =  (100 - perc_hcv) * 0.01 * site_carbon_summary$carbon_mean[3] +
                     perc_hcv * 0.01 * site_carbon_summary$Q025[2], # OP mean plus HCV 2.5th quantile
                   C_975 =  (100 - perc_hcv) * 0.01 * site_carbon_summary$carbon_mean[3] +
                     perc_hcv * 0.01 * site_carbon_summary$Q975[2])# OP mean plus HCV 97.5th quantile



# increase in AGC of plantation if 10% set-aside coverage added (average set-aside AGC)
hcv_perc[hcv_perc$perc_hcv == 10,]$C_mean - hcv_perc[hcv_perc$perc_hcv == 0,]$C_mean
# 2.344672

# as % increase from 0
(hcv_perc[hcv_perc$perc_hcv == 10,]$C_mean - hcv_perc[hcv_perc$perc_hcv == 0,]$C_mean)*100/hcv_perc[hcv_perc$perc_hcv == 0,]$C_mean

# increase in AGC of plantation if 10% set-aside coverage added (97.5th percentile set-aside AGC)
hcv_perc[hcv_perc$perc_hcv == 10,]$C_975 - hcv_perc[hcv_perc$perc_hcv == 0,]$C_975
# 6.126508

# as % increase from 0
(hcv_perc[hcv_perc$perc_hcv == 10,]$C_975 - hcv_perc[hcv_perc$perc_hcv == 0,]$C_975)*100/hcv_perc[hcv_perc$perc_hcv == 0,]$C_975
# 20.19617


# improving AGC in set-asides for plantation with 10% coverage of set-asides
# average set-aside AGC to 97.5th percentile
hcv_perc[hcv_perc$perc_hcv == 10,]$C_975 - hcv_perc[hcv_perc$perc_hcv == 10,]$C_mean # 3.781836
# as % 
(hcv_perc[hcv_perc$perc_hcv == 10,]$C_975 - hcv_perc[hcv_perc$perc_hcv == 10,]$C_mean) * 100/hcv_perc[hcv_perc$perc_hcv == 10,]$C_mean
# 11.57%


# improving AGC in set-asides for plantation with 10% coverage of set-asides
# 2.5th percentile set-aside AGC to 97.5th percentile
hcv_perc[hcv_perc$perc_hcv == 10,]$C_975 - hcv_perc[hcv_perc$perc_hcv == 10,]$C_025 # 6.256159
# as % 
(hcv_perc[hcv_perc$perc_hcv == 10,]$C_975 - hcv_perc[hcv_perc$perc_hcv == 10,]$C_025) * 100/hcv_perc[hcv_perc$perc_hcv == 10,]$C_025
# 20.71209



ggplot(data = hcv_perc)+
  geom_line(aes(x = perc_hcv,
                y = C_mean),
            size = 0.8)+
  geom_ribbon(aes(x = perc_hcv,
                  ymax = C_high,
                  ymin = C_low),
              alpha = 0.7,
              fill = "#8F8F8F")+
  geom_line(aes(x = perc_hcv,
                y = C_025),
            size = 0.8,
            linetype = "dashed",
            colour = "#656565")+
  geom_line(aes(x = perc_hcv,
                y = C_975),
            size = 0.8,
            linetype = "dashed",
            colour = "#656565")+
  geom_point(aes(x = 100,
                 y = site_carbon_summary$carbon_mean[1]), # cont C high
             colour = "#287A1C",
             size = 3)+ # this is the midpoint of the 2 colours for cont forest (PREVIOUS COLOURS)
  geom_errorbar(aes(x = 100,
                 ymax = site_carbon_summary$PI_upr[1],
                 ymin = site_carbon_summary$PI_lwr[1]), # cont C high
             colour = "#287A1C",
             width = 6,
             size = 0.8)+ # this is the midpoint of the 2 colours for cont forest (PREVIOUS COLOURS)
  geom_point(aes(x = 0,
                 y = site_carbon_summary$carbon_mean[3]), # cont C high
             colour = "#87621a",
             size = 3)+ # this is the midpoint of the 2 colours for cont forest (PREVIOUS COLOURS)
  geom_errorbar(aes(x = 0,
                    ymax = site_carbon_summary$PI_upr[3],
                    ymin = site_carbon_summary$PI_lwr[3]), # cont C high
                colour = "#87621a",
                width = 6,
                size = 0.8)+
  theme_classic() +
  theme(panel.grid.major = element_line(colour = "lightgrey"),
        panel.grid.minor = element_line(colour = "lightgrey"),
        plot.margin = unit(c(10, 10, 0, 10), "points")) +
  xlab(gsub("_", "\n", "% set-aside cover in_oil palm plantation")) +
  ylab(expression("Expected average AGC\n   of plantation / Mg ha"^-1*""))+ # need spaces to because the superscript stays at end of line...
  coord_cartesian(ylim=c(0,150),
                  xlim = c(0,100))




